@@ -79,10 +79,8 @@ if [ -d /otu/log ] ; then
     echo "${CURRENT_DATE} : Boot using partition ${CURRENT_PART}" >> /otu/log/boot.log
     if [ -f /proc/device-tree/board/rescue-mode ] && [ $(cat /proc/device-tree/board/rescue-mode) == "yes" ] ; then
         echo "${CURRENT_DATE} : Started in rescue mode" >> /otu/log/boot.log
-        echo 1 > /sys/class/leds/led_unit_red/brightness
-        echo 1 > /sys/class/leds/led_server_red/brightness
-        echo 1 > /sys/class/leds/led_optic_red/brightness
-        echo 1 > /sys/class/leds/led_testing_red/brightness
+        # We want to try again to boot normally at next reboot
+        otu_confirm_start.sh
     fi
 fi
 
