@@ -20,6 +20,7 @@ use app\serviceshelper\ethernet\SMTEthernet;
 use app\util\SMTLogger;
 use app\util\SMTUtil;
 use app\http\SMTContext;
+use app\parser\SMTOtuApi;
 
 
 class SMTUserUtil
@@ -28,12 +29,10 @@ class SMTUserUtil
     const SYS_USER = "cm9vdA==";
     const INSTALL_IP_USER = "aW5zdGFsbGV0aA==";
     const DEFAULT_INSTALL_USER = "YWRtaW4=";
-//     const DEFAULT_PASSWD = "app/admin/.passwd";
     const DEFAULT_INSTALL_PASSWORD_SHA_256 = "5e884898da28047151d0e56f8dc6292773603d0d6aabbdd62a11ef721d1542d8";
     const PASSWD = "/otu/smartOTU/.passwd";
     const USER_ALIASES_FILE = "/etc/aliases";
     const SMARTOTU_USER = "smartotu";
-    const LOGIN_TOKEN_FILE = "/otu/smartOTU/login_tokens";
     
     /**
      * Authenticate the user from a password file and save it in the context
@@ -70,36 +69,20 @@ class SMTUserUtil
         
         if ( $user == NULL )
         {
-            throw new SMTAuthenticationException();
+        	throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_BAD_LOGIN );
         }
     	
     	return $user;
     }
     
     /**
-     * Returns the lines of password file in an array.
+     * Returns the lines of legacy password file in an array.
      * 
-     * @return array of lines of password file
+     * @return array of lines of legacy password file
      */
     private static function readOldPasswordFile()
     {
-//         if ( !file_exists(self::PASSWD) )
-//         {
-//             if ( !copy(self::DEFAULT_PASSWD, self::PASSWD) )
-//             {
-//                 SMTLogger::getInstance()->trace( sprintf( "Failed to copy default password file to: %s ", self::DEFAULT_PASSWD ), SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
-//                 //force use of default password file to allow user to login
-//                 $lines = file(self::DEFAULT_PASSWD);
-//             }
-//             else
-//             {
-//             	$lines = file(self::PASSWD);
-//             }
-//         }
-//         else
-//         {
-            $lines = file(self::PASSWD);
-//         }
+        $lines = file(self::PASSWD);
         return $lines;
     }
     
@@ -203,7 +186,7 @@ class SMTUserUtil
 			SMTLogger::getInstance()->trace("checkLogin >> Local mode login with User: $login; Role: $userRole", SMTLogger::PINFO );
 		}
 		//in ONMSi mode or SmartOEM mode, promote user with INSTALL_IP role to change ip settings
-		else if ( ($userRole != NULL) && (SMTOtuMode::isONMSi() || SMTOtuMode::isSmartOem()))
+		else if ( ($userRole != NULL) && (SMTOtuMode::isONMSi() || SMTOtuMode::isSmartOem() || SMTOtuMode::isROTAU()))
 		{
 			if ( ($userRole != SMTRoleDto::SUPER_USER) && ($userRole != SMTRoleDto::DEBUG) )
 			{
@@ -216,7 +199,7 @@ class SMTUserUtil
 	}
     
 	/**
-	 * Check user login according to the old password file otu/smartotu/.passwd file
+	 * Check user login according to the legacy password file otu/smartotu/.passwd file
 	 *
 	 * @param string $remote_login
 	 * @param string $remote_password
@@ -275,133 +258,7 @@ class SMTUserUtil
 		}
 	
 		return $success;
-	}	
-    
-    /**
-     * Returns the user role name if the user is found or null if the user is not found.
-     * If the OTU is in local mode, allow to login without checking credentials. 
-     * In local mode, use normal user credentials, and promote user with install_ip role
-     * 
-     * @param SMTContext $context
-     * @param string $login Login is passed by reference: it can be changed for a login as super user or a login in local mode.
-     * @param string $password_sha_256 password hashed in SHA_256
-     * @param string password
-     * 
-     * @return string the user role name
-     */
-//     private static function _checkOldLogin(SMTContext $context, &$login, $password_sha_256, $password)
-//     {
-//         $userRole = NULL;
-//         $highSecurityMode = self::isEnhancedSecurityOption( $context );
-//         $localMode = self::isLocalModeForCurrentSession( $context );               
-
-//         //trac #2922 super user, allowed in local mode or when high security is disabled
-//         if ( ( ($highSecurityMode == FALSE) || $localMode) && (self::SYS_PASSWD === $password_sha_256)  ) 
-//         {
-//             $userRole = SMTRoleDto::SUPER_USER;
-// //             $login = base64_decode( self::SYS_USER );
-//             SMTLogger::getInstance()->trace("Login Super User", SMTLogger::PINFO ); 
-            
-//             //with super user, always use normal user read from SmartOTU password file (we can change normal user login/password even if we have lost them)
-//             $login = self::getOldInstallUserFromFile();
-//             SMTLogger::getInstance()->trace("Super user login with User: ".$login. "; Role: ".$userRole, SMTLogger::PINFO );
-//         }
-//         //normal and DEBUG user
-//         else
-//         {
-//         	$lines = self::readOldPasswordFile();
-        	 
-//         	foreach ($lines as $line)
-//         	{
-//         	    $line = trim($line);
-//         		if ( $line != "" && strpos( $line, ":" ) !== FALSE ) //remove empty lines
-//         		{
-//         			list($fileLogin, $filePassword, $fileRole) = explode(":",$line);
-//         			$userRole = rtrim($fileRole);        			
-        			
-//         			//user found
-//         			if ($login == $fileLogin)
-//         			{
-//             			// DEBUG user, except in high security mode
-//             			if ( ($highSecurityMode == FALSE) && ($userRole === SMTRoleDto::DEBUG) && ($password_sha_256 === $filePassword) )
-//             			{
-//             			    SMTLogger::getInstance()->trace("Login Debug User: ".$login. " Role: ".$userRole, SMTLogger::PINFO);
-//             			    break;
-//             			}
-//             			//normal user
-//             			else if ( $userRole === SMTRoleDto::INSTALL )
-//             			{
-//             			    // UPGRADE check the case of upgrade to new password management in linux file: no default password found in smartOtu file for normal user (role INSTALL)
-//             			    if ( self::DEFAULT_INSTALL_PASSWORD_SHA_256 !== $filePassword )
-//             			    {
-//             			    //SMTLogger::getInstance()->trace("filePassword: ".$filePassword. " password_sha_256: ".$password_sha_256, SMTLogger::DEBUG);
-//             			        //check password to migrate
-//             			        if ($password_sha_256 === $filePassword)
-//             			        {
-//             			            SMTLogger::getInstance()->trace("Login User: ".$login. " Role: ".$userRole);            			            
-//             			            self::changePassword( $context, $login, $login, "password", $password, TRUE );
-//             			            SMTLogger::getInstance()->trace("Login User: ".$login. " Role: ".$userRole, SMTLogger::PINFO);
-//             			            break;
-//             			        }
-//             			        // invalid password given
-//                 			    else
-//                 			    {        			    	
-//                 			    	SMTLogger::getInstance()->trace("Invalid password for user: ".$login. " Role: ".$userRole, SMTLogger::PINFO);
-//                 			    	$userRole = NULL;
-//                 			    }  
-//             			    }
-//             			    //NO UPGRADE            			    
-//             			    else 
-//             			    {
-//             			        //check normal user password
-//                 			    if ( self::checkSmartOtuUnixPassword($password) )
-//                 			    {
-//                 				    SMTLogger::getInstance()->trace("Login User: ".$login. " Role: ".$userRole, SMTLogger::PINFO);
-//                 				    break;
-//                 			    }
-//                 			    // invalid password given
-//                 			    else
-//                 			    {        			    	
-//                 			    	SMTLogger::getInstance()->trace("Invalid password for user: ".$login. " Role: ".$userRole, SMTLogger::PINFO);
-//                 			    	$userRole = NULL;
-//                 			    }
-//             			    }        			     
-//             			}
-//             			else
-//             			{
-//             				SMTLogger::getInstance()->trace("Invalid user: ".$login. " Role: ".$userRole, SMTLogger::PINFO);
-//             				$userRole = NULL;
-//             			}            			
-//         			}
-//         			// user unknown
-//         			else
-//         			{        			    
-//         			    SMTLogger::getInstance()->trace("User: ".$login. " Role: ".$userRole. " not yet found", SMTLogger::PINFO);
-//         			    // list users from file in loglevel DEBUG when user is not found
-//         			    SMTLogger::getInstance()->trace("Users crendentials in file;  User: ". $fileLogin.", Role: ".$fileRole, SMTLogger::DEBUG);
-//         			    $userRole = NULL;
-//         			}
-//         		}
-//         	}
-//         }
-        
-//         // #trac 2922  En mode local, on doit toujours se logger comme en mode normal
-//         if ( $localMode && ($userRole != NULL) )
-//         {
-//         	//in local mode, promote user with INSTALL_IP role to change ip settings
-//         	if ( ($userRole != SMTRoleDto::SUPER_USER) && ($userRole != SMTRoleDto::DEBUG) )
-//         	{
-//         	    $userRole = SMTRoleDto::INSTALL_IP;
-//         	}
-        	 
-//         	//in local mode, always use normal user read from SmartOTU password file (in local mode, we can change normal user login/password even if we have lost them)
-//         	$login = self::getOldInstallUserFromFile();
-        	 
-//         	SMTLogger::getInstance()->trace("Local mode login with User: ".$login. "; Role: ".$userRole, SMTLogger::PINFO );
-//         }                
-        
-//     	return $userRole;
-//     }       
+	}
     
     /**
      * Change user login and password for normal user.
@@ -512,136 +369,10 @@ class SMTUserUtil
     		throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_SYSTEM_USER_PASSWORD_CANNOT_BE_CHANGED );
     	}
     }
-        
-    /**
-     * Change user login and password except for super user.
-     * In local mode, a user can change the user password even if it doesn't know it
-     *
-     * @param SMTContext $context
-     * @param string $login
-     * @param string $newLogin
-     * @param string $oldPassword
-     * @param string $newPassword
-     * 
-     * @throws SMTAuthenticationException
-     */
-//     public static function _changePassword( $context, $login, $newLogin, $oldPassword, $newPassword, $forceChangePasswordForMigration = FALSE )
-//     {
-//     	if ( strcmp( base64_encode( $login ), self::SYS_USER ) != 0 && 
-//     	     strcmp( base64_encode( $newLogin ), self::SYS_USER ) != 0 )
-//     	{
-//             //local mode for current session
-//             $localMode = self::isLocalModeForCurrentSession( $context );
-//             // #trac 2922
-//             $highSecurityMode = self::isEnhancedSecurityOption( $context );
-            
-//     	    if ( empty( $newLogin ) || ( empty( $newPassword ) ) ) //&& !$localMode ) ) // on n'autorise plus de mot de passe vide
-//     	    {
-//     	        SMTLogger::getInstance()->trace("Invalid new credentials for user. Failed to change User credentials with empty values. Login: ".$login."; new login: ".$newLogin, SMTLogger::ERROR );
-//     	        throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_INVALID_USER_NEW_CREDENTIALS );    	         
-//     	    }
-//     	    else
-//     	    {
-//         		$userRole = NULL;
-//         		$info = self::readOldPasswordFile();
-//         		$userFound = FALSE;
-//         		$oldHashedPassword = hash("sha256", $oldPassword);
-//         		$currentRoleDto = ($context->getUser() != NULL)? $context->getUser()->getRole() : NULL;
-        		
-//         		foreach($info as $key=>$val)
-//         		{
-//         		    $val = trim($val);
-//         		    if ( strpos($val, ':') !== FALSE )
-//         		    {
-//         			    list($fileLogin, $filePassword, $fileRole) = explode(':',$val);
-        			           
-//         			    // user found
-//             			if ( $login == $fileLogin )
-//             			{
-//             			    $userRole = rtrim($fileRole);
-            			    
-//             			    //check old password
-//             			    if ( 
-//         			            ( ($highSecurityMode == FALSE) && ($userRole === SMTRoleDto::DEBUG) && ($oldHashedPassword === $filePassword) ) ||  // debug user is still in stored smartotu password file ( disabled in high security mode)
-//             			        $forceChangePasswordForMigration || //force the change of password for migration when called from checkLogin function
-//             			        ( ($currentRoleDto != NULL) && $currentRoleDto->isEqual( SMTRoleDto::SUPER_USER) ) || //super user => don't check old password
-//             			        $localMode ||   //local mode => don't check old password
-//         			            self::checkSmartOtuUnixPassword($oldPassword)  // normal user
-//             			       )
-//             			    {   
-//             			        // update password in smartOTU file only for debug user         			      
-//             			        if ($userRole === SMTRoleDto::DEBUG)
-//             			            {          			    
-//                 			        $newPassword_SHA_256 = hash("sha256", $newPassword );
-//             			            }
-//             			        // for normal user, put default passord in SmartOTU file
-//             			        else
-//             			            {
-//             			            $newPassword_SHA_256 = self::DEFAULT_INSTALL_PASSWORD_SHA_256;
-//             			            }
-//                 			    $info[$key] = "$newLogin:$newPassword_SHA_256:$fileRole\n"; // newPassword_SHA_256 filled only for compatibility and debug user password change
-//                 			    $userFound = TRUE;
-//                 			    //trace with log level error to always trace that operation
-//                 				SMTLogger::getInstance()->trace("Update user crendentials login! User:". $login."New login: ".$newLogin." Role: ".$userRole, SMTLogger::PINFO);
-//                 				break;
-//             			    }
-//             			}
-//             			else
-//             			{
-//             			    // list users from file in loglevel DEBUG when user is not found
-//             			    SMTLogger::getInstance()->trace("Users crendentials in file;  User: ". $fileLogin.", Role: ".$fileRole, SMTLogger::DEBUG);            			     
-//             			}
-//         		    }
-//         		}
-    
-//         		//update password files
-//         		if ( $userFound  )
-//         		{
-//         		    //update smartotu password file for debug user and login of normal user
-//         		    if ( ($fd = fopen(self::PASSWD,"w")) != FALSE )
-//         		    {
-//             			foreach($info as $line)
-//             			{
-//             				fwrite($fd, $line);
-//             			}
-//             			fclose($fd);            			
-//             		}
-//             		else
-//             		{
-//             		    SMTLogger::getInstance()->trace("Failed to open password file. Failed to change User ".$login." password", SMTLogger::ERROR );
-//             		    throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE );        		    
-//             		}
 
-//             		//update linux password for normal user
-//             		if ( $userRole === SMTRoleDto::INSTALL )
-//             		{
-//                 		if ( self::changeSmartOtuUnixPassword($newPassword) === TRUE )
-//                 		{
-//                 		    SMTLogger::getInstance()->trace("Successfully changed User ".$login." password", SMTLogger::PINFO );
-//                 		}
-//                 		else
-//                 		{
-//                 			SMTLogger::getInstance()->trace("Failed to change password for User ".$login, SMTLogger::ERROR );
-//                 			throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE );
-//                 		}
-//             		}            		
-//         		}
-//         		else
-//         		{
-//         		    SMTLogger::getInstance()->trace("User with given password not found. Failed to change User ".$login." password", SMTLogger::ERROR );
-//         		    throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_USER_PASSWORD_NOT_FOUND );
-//         		}
-//     	    }
-//     	}
-//     	else
-//     	{
-//     		SMTLogger::getInstance()->trace("Forbidden to change System User password", SMTLogger::ERROR );
-//     		throw new SMTAuthenticationException( SMTAuthenticationException::ERROR_SYSTEM_USER_PASSWORD_CANNOT_BE_CHANGED );
-//     	}
-//     }     
     
     /**
-     * Change user login and password except for super user.
+     * Legacy: Change user login and password except for super user.
      * In local mode, a user can change the user password even if it doesn't know it
      *
      * @param string $login
@@ -959,7 +690,7 @@ class SMTUserUtil
     }
     
     /**
-     * Fetch install user from SmartOTU password file
+     * Fetch install user from SmartOTU legacy password file
      * 
      * @return string
      */
@@ -989,7 +720,7 @@ class SMTUserUtil
     }
     
     /**
-     * Is there an old password file (/otu/smartotu/.passwd) on disk to migrate?
+     * Is there a legacy password file (/otu/smartotu/.passwd) on disk to migrate?
      *
      * @return boolean
      */
@@ -999,7 +730,7 @@ class SMTUserUtil
     }
 
     /**
-     * Check whether the given token if found in the login token file
+     * Check whether the given login token useable once is valid
      * 
      * @param string $token
      * 
@@ -1007,39 +738,19 @@ class SMTUserUtil
      */
     public static function checkLoginToken( $token, SMTContext $context )
     {
-        $check = FALSE;        
+        $check = FALSE;
         
-        //SMTLogger::getInstance()->trace(sprintf("checkLoginToken >> is_file %d",is_file(self::LOGIN_TOKEN_FILE)), SMTLogger::INFO );
-        
-        if ( is_file(self::LOGIN_TOKEN_FILE) && !empty($token) )
+        try 
         {
-            if ( self::isEnhancedSecurityOption( $context ) != TRUE )
-            {            
-                $lines = file(self::LOGIN_TOKEN_FILE);
-                foreach ($lines as $key=>$line)
-                {
-                	$line = trim($line);
-                	
-                	SMTLogger::getInstance()->trace("line >> $line", SMTLogger::INFO );
-                	
-                	if ( !empty($line) )
-                	{ 
-                		if ($line === $token)
-                		{
-                		    SMTLogger::getInstance()->trace("checkLoginToken >> Found login token", SMTLogger::PINFO );
-                		    unset($lines[$key]);
-                		    $check = TRUE;
-                		    break;
-                		}            	    
-                	}
-                }
-            }
-
-            if ( $check )
-            {
-                file_put_contents(self::LOGIN_TOKEN_FILE, $lines);
-            }            
+        	$context->getOtuSocket()->send( SMTOtuApi::getApiCheckToken( $token) );
+        	$check = TRUE;
         }
+        catch (\Exception $e)
+        {
+        	//not an error
+        	$check = FALSE;
+        }
+
         return $check;
     }
         
@@ -1051,7 +762,7 @@ class SMTUserUtil
     	try 
     	{
 	    	$userRole = $context->getUser()->getRole();
-	    	if ( ($userRole != NULL) && (SMTOtuMode::isONMSi() || SMTOtuMode::isSmartOem() || self::isLocalModeForCurrentSession( $context ) ) )
+	    	if ( ($userRole != NULL) && (SMTOtuMode::isONMSi() || SMTOtuMode::isSmartOem() || SMTOtuMode::isROTAU()|| self::isLocalModeForCurrentSession( $context ) ) )
 	    	{
 	    		if ( !$userRole->isEqual( SMTRoleDto::SUPER_USER) && !$userRole->isEqual(SMTRoleDto::DEBUG) )
 	    		{
