@@ -25,56 +25,56 @@ class SMTOtuApi
     /**
      * OTU parser default constant parameters
      */
-    const EMPTY_BUFFER = "#10";
+    const EMPTY_BUFFER = '#10';
     
     /**
      * Media 1: Email
      *
      * @var string
      */
-    const MEDIA_1 = "ALT1";
+    const MEDIA_1 = 'ALT1';
     
     /**
      * Media 2: SMS
      *
      * @var string
      */
-    const MEDIA_2 = "ALT2";
+    const MEDIA_2 = 'ALT2';
     
     /**
      * Media 3: SNMP
      *
      * @var string
      */
-    const MEDIA_3 = "ALT3";
+    const MEDIA_3 = 'ALT3';
     
     /**
      * internal modem for SMS
      * 
      * @var string
      */
-    const MODEM_INTERNAL_1 = "INT1";    
+    const MODEM_INTERNAL_1 = 'INT1';
         
     /**
      * Email media.
      *
      * @var string
      */
-    const EMAIL_MEDIA = "EMAIL";    
+    const EMAIL_MEDIA = 'EMAIL';
     
     /**
      * Sms media.
      *
      * @var string
      */
-    const SMS_MEDIA = "SMS";
+    const SMS_MEDIA = 'SMS';
 
     /**
      * SNMP media.
      *
      * @var string
      */
-    const SNMP_MEDIA = "SNMP";
+    const SNMP_MEDIA = 'SNMP';
     
     /**
      * Only one SNMP config
@@ -103,42 +103,47 @@ class SMTOtuApi
      */
     const MEDIA_RETRY_DELAY = 600; //10mn
     
-    const LOG_LEVEL_ERROR = "ERR";
-    const LOG_LEVEL_INFO = "INFO";
-    const LOG_LEVEL_DEBUG = "DEBUG";
+    const LOG_LEVEL_ERROR = 'ERR';
+    const LOG_LEVEL_INFO = 'INFO';
+    const LOG_LEVEL_DEBUG = 'DEBUG';
     
     /**
      * OTU PARSER RESULT STATUS
      */
-    const RES_OK = "OK";
-    const RES_KO = "KO";
-    const RES_ON = "ON";
-    const RES_OFF = "OFF";
-    const RES_MISSCONF = "MISSconf";
-    const RES_MISSDET = "MISSdet";
-    const RES_SAME = "SAME";
-    const RES_DIFF = "DIFF";
-    const RES_NO = "NO";
-    const RES_NONE = "NONE";
-    const RES_UNKNOWN = "???";
-    const RES_UNKNOWN_AF = "Unknown AF";
-    const RES_YES = "YES";
-    const RES_MOD = "MOD";
-    const RES_ALL = "ALL";
-    const RES_WEB = "WEB";
-    const RES_READY = "READY";
-    const RES_VALID = "VALID";
-    const FIREWALL_OFF_OLD = "ENABLE";
-    const FIREWALL_ON_OLD = "DISABLE";
-    const FIREWALL_OFF = "DISABLE";
-    const FIREWALL_ON =  "DEFAULT";
-    const FIREWALL_CUSTOM = "CUSTOM";
-    const RES_OPT = "OPT";
-    const RES_SYST = "SYST";
-    const RES_BOTH = "BOTH";
+    const RES_OK = 'OK';
+    const RES_KO = 'KO';
+    const RES_ON = 'ON';
+    const RES_OFF = 'OFF';
+    const RES_MISSCONF = 'MISSconf';
+    const RES_MISSDET = 'MISSdet';
+    const RES_SAME = 'SAME';
+    const RES_DIFF = 'DIFF';
+    const RES_NO = 'NO';
+    const RES_NONE = 'NONE';
+    const RES_UNKNOWN = '???';
+    const RES_UNKNOWN_AF = 'Unknown AF';
+    const RES_YES = 'YES';
+    const RES_MOD = 'MOD';
+    const RES_ALL = 'ALL';
+    const RES_WEB = 'WEB';
+    const RES_READY = 'READY';
+    const RES_VALID = 'VALID';
+    const FIREWALL_OFF_OLD = 'ENABLE';
+    const FIREWALL_ON_OLD = 'DISABLE';
+    const FIREWALL_OFF = 'DISABLE';
+    const FIREWALL_ON =  'DEFAULT';
+    const FIREWALL_CUSTOM = 'CUSTOM';
+    const RES_OPT = 'OPT';
+    const RES_SYST = 'SYST';
+    const RES_BOTH = 'BOTH';
     const RES_DISABLED = 'DISABLED';
     const RES_ENABLED = 'ENABLED';
+    const LEGACY_MODE = 'LEG';
+    const HIGHSENS_MODE = 'HIGH';
     
+    const RES_WAIT   ='WAIT';
+    const RES_ENABLE = 'ENABLE';
+    const RES_DISABLE = 'DISABLE';
     
     const OTU_MAX_ADDITIONAL_INFO_LENGTH = 30;
     
@@ -246,6 +251,33 @@ class SMTOtuApi
     {
     	return sprintf( self::CMD_Get_Min_Attenuation_Alarm_Threshold, $module );
     }
+    const CMD_Get_Min_Hysteresis_Attenuation_Alarm_Threshold= 'OTU:MON:ATT:HYSM? %s';
+    
+    /**
+     * @param string $module MOD1, MOD2 or MOD3
+     * @return string
+     */
+    static function getMinHysteresisAttenuationAlarmThreshold($module)
+    {
+    	return sprintf( self::CMD_Get_Min_Hysteresis_Attenuation_Alarm_Threshold, $module );
+    }
+    
+    const CMD_Get_List_Hysteresis_Attenuation_Alarm_Threshold= 'OTU:MON:ATT:HYSL? %s';
+    
+    /**
+     * @param string $module MOD1, MOD2 or MOD3
+     * @return string
+     */
+    static function getHysteresisAttenuationAlarmThresholdList($module)
+    {
+    	return sprintf( self::CMD_Get_List_Hysteresis_Attenuation_Alarm_Threshold, $module );
+    }
+    
+    const CMD_Get_Critical_Threshold='OTU:MON:CUT? %d';
+    static function getGet_Critical_Threshold($testId)
+    {
+    	return sprintf( self::CMD_Get_Critical_Threshold, $testId);
+    }
     
     /**
      * MOD3, MOD2 or MOD1
@@ -289,6 +321,19 @@ class SMTOtuApi
 //      * MOD2 or MOD1, function, L1 or L2...
 //      */    
 //     const CMD_get_Injection = 'OTU:MODU:DETLaser:INJT? %s,"%s",%s';   
+    /**
+     * MOD2 or MOD1, function command
+     * @returns minGhz,maxGhz,spacingGhz
+     */
+    const CMD_get_Frequency_Setup = 'OTU:DWDM:PARAMETERS? %s';
+    /**
+     * @param string $module MOD1 or MOD2
+     * @returns minGhz,maxGhz,spacingGhz
+     */
+    static function getModuleFrequencyParameters( $module )
+    {
+    	return sprintf( self::CMD_get_Frequency_Setup, $module );
+    }   
     /**
      * MOD2 or MOD1, function command
      * @returns 1625,...
@@ -931,13 +976,13 @@ class SMTOtuApi
     // ROTAU
     //**********************
     const CMD_is_otu_ROTAU = 'OTU:ROTAU?';      
-    const CMD_verify_ROTAU = 'OTU:SWITCH:DETECT:IPOTU:VERIFY? "%s"';//IP address: verify that an OTU is a ROTAU   
+    const CMD_verify_ROTAU = 'OTU:SWITCH:DETECT:IPROTAU:NVER? "%s"';//IP address: verify that an OTU is a ROTAU   
     const CMD_get_rotau_sn_conf = 'OTU:SWITCH:CONFIG:SERIAL? %d,GLOB'; //1,2,...
     const CMD_get_rotau_sn_det = 'OTU:SWITCH:DET:SERIAL? %d,GLOB'; //1,2,...
     const CMD_switch_detect_calib_desc = 'OTU:SWITCH:CONFIG:DETECT:DESC? %d,%s';//0...,GLOB
-    const CMD_switch_detect_add_chaine_ROTAU = 'OTU:SWITCH:DETECT:IPOTU:ADD "%s"';//String IP ROTAU
-    const CMD_switch_config_add_chaine_ROTAU = 'OTU:SWITCH:CONFIG:ROTAUADD? "%s",%s,"%s"';//String IP ROTAU, RTU, String switch code
-    const CMD_switch_detect_remove_chaine_ROTAU = 'OTU:SWITCH:DETECT:IPOTU:DEL "%s"';//String IP ROTAU
+    const CMD_switch_detect_add_chaine_ROTAU = 'OTU:SWITCH:DETECT:IPROTAU:NADD "%s"';//String IP ROTAU
+    const CMD_switch_config_add_chaine_ROTAU = 'OTU:SWITCH:CONFIG:NROTAUADD? %s,"%s","%s"';// IP_ROTAU, String switch code, String IP
+    const CMD_switch_detect_remove_chaine_ROTAU = 'OTU:SWITCH:DETECT:IPROTAU:NDEL "%s"';//String IP ROTAU
     
     //****************
     //* measurement
@@ -979,11 +1024,11 @@ class SMTOtuApi
     const CMD_ind_ref = 'OTU:INDEX:DEFAULT? '; 
     
     /**
-     * //module, switches number, switch ASCII buffer// auto Config (AUTO, MANUAL) // pulse //range KM // duration s // refraction index // wavelength // resolution // function
+     * //module, switches number, switch ASCII buffer// auto Config (AUTO, MANUAL) // pulse //range KM // duration s // refraction index // wavelength // resolution // function// short acq
      */
-    const CMD_acquisition_otdr_SI = 'OTU:MEALINK:SI:WEBCONFIG? %s,%d,%s,%s,%d,%F,%d,%F,%d,%d,"%s"';
+    const CMD_acquisition_otdr_SI = 'OTU:MEALINK:SI:CONFIG? %s,%d,%s,%s,%d,%F,%d,%F,%d,%d,"%s",%s';
     /**
-     * Execute a measurement on a link command
+     * Execute a measurement on demand command
      *
      * @param string $module
      * @param integer $switchCount 
@@ -996,18 +1041,47 @@ class SMTOtuApi
      * @param integer $wavelengthNm
      * @param integer $resolutionCm
      * @param string $function
+     * @param boolean $shortAcq
+     * 
+     * @return string
+     */
+    static function getExecuteMeasurementCommand( $module, $switchCount, $switchBuffer, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function, $shortAcq )
+    {
+    	return sprintf( self::CMD_acquisition_otdr_SI, $module, $switchCount, $switchBuffer, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function, $shortAcq? self::RES_YES : self::RES_NO);
+    }
+    
+    /**
+     * //module, switches number, switch ASCII buffer// auto Config (AUTO, MANUAL) // pulse //range KM // duration s // refraction index // wavelength // resolution // function// short acq// frequency
+     */
+    const CMD_acquisition_DWDM_SI= 'OTU:MEALINK:SI:DWDM? %s,%d,%s,%s,%d,%F,%d,%F,%d,%d,"%s",%s,%d';
+    /**
+     * Execute a dwdm measurement on demand command
+     *
+     * @param string $module
+     * @param integer $switchCount
+     * @param string $switchBuffer
+     * @param string $autoConfigMode //AUTO, MANUAL
+     * @param integer $pulseNs
+     * @param float $rangeKM
+     * @param integer $durationSec
+     * @param float $refractionIndex
+     * @param integer $wavelengthNm
+     * @param integer $resolutionCm
+     * @param string $function
+     * @param boolean $shortAcq
+     * @param int $frequency
      *
      * @return string
      */
-    static function getExecuteMeasurementCommand( $module, $switchCount, $switchBuffer, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function )
+    static function getExecuteDwdmMeasurementCommand( $module, $switchCount, $switchBuffer, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function, $shortAcq, $frequency )
     {
-    	return sprintf( self::CMD_acquisition_otdr_SI, $module, $switchCount, $switchBuffer, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function );
-    }    
+    	return sprintf( self::CMD_acquisition_DWDM_SI, $module, $switchCount, $switchBuffer, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function, $shortAcq? self::RES_YES : self::RES_NO, $frequency);
+    }
     
     /**
-     * link Id // auto Config (AUTO, MANUAL) // pulse //range KM // duration s // refraction index // wavelength // resolution // function
+     * link Id // auto Config (AUTO, MANUAL) // pulse //range KM // duration s // refraction index // wavelength // resolution // function // short acq
      */   
-    const CMD_acquisition_on_link_SI = 'OTU:MEASURE:SI:WEBCONFIG? %d,%s,%d,%F,%d,%F,%d,%d,"%s"';//numero de liaison, programmation autoconfig, valeur du pulse, Valeur de la portee, duree acq, Indice de refraction, Valeur du laser, Valeur de la resolution, Nom de la fonction                       
+    const CMD_acquisition_on_link_SI = 'OTU:MEASURE:SI:SMARTCONFIG? %d,%s,%d,%F,%d,%F,%d,%d,"%s",%s';//numero de liaison, programmation autoconfig, valeur du pulse, Valeur de la portee, duree acq, Indice de refraction, Valeur du laser, Valeur de la resolution, Nom de la fonction, short acq                       
     /**
      * Execute a measurement on a link command
      * 
@@ -1020,13 +1094,40 @@ class SMTOtuApi
      * @param integer $wavelengthNm
      * @param integer $resolutionCm
      * @param string $function
+     * @param boolean $shortAcq
      * 
      * @return string
      */
-    static function getExecuteMeasurementOnLinkCommand( $linkId, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function )
+    static function getExecuteMeasurementOnLinkCommand( $linkId, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function, $shortAcq)
     {
-    	return sprintf( self::CMD_acquisition_on_link_SI, $linkId, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function );
-    }     
+    	return sprintf( self::CMD_acquisition_on_link_SI, $linkId, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function, $shortAcq? self::RES_YES : self::RES_NO);
+    }
+    
+    /**
+     * link Id // auto Config (AUTO, MANUAL) // pulse //range KM // duration s // refraction index // wavelength // resolution // function // short acq
+     */
+    const CMD_acquisition_on_link_DWDM = 'OTU:MEASURE:SI:DWDM? %d,%s,%d,%F,%d,%F,%d,%d,"%s",%s,%d';//numero de liaison, programmation autoconfig, valeur du pulse, Valeur de la portee, duree acq, Indice de refraction, Valeur du laser, Valeur de la resolution, Nom de la fonction, short acq
+    /**
+     * Execute a measurement on a link command
+     *
+     * @param integer $linkId
+     * @param string $autoConfigMode //AUTO, MANUAL
+     * @param integer $pulseNs
+     * @param float $rangeKM
+     * @param integer $durationSec
+     * @param float $refractionIndex
+     * @param integer $wavelengthNm
+     * @param integer $resolutionCm
+     * @param string $function
+     * @param boolean $shortAcq
+     * @param int     $frequency
+     *
+     * @return string
+     */
+    static function getExecuteMeasurementOnLinkDwdmCommand( $linkId, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function, $shortAcq, $frequency)
+    {
+    	return sprintf( self::CMD_acquisition_on_link_DWDM, $linkId, $autoConfigMode, $pulseNs, $rangeKM, $durationSec, $refractionIndex, $wavelengthNm, $resolutionCm, $function, $shortAcq? self::RES_YES : self::RES_NO, $frequency);
+    }
         
     const CMD_meas_add_status = 'OTU:MEAS:ADD:STATUS?';
     /**
@@ -1061,6 +1162,17 @@ class SMTOtuApi
     	return self::CMD_stop_measure;
     }
     
+    const CMD_meas_som_eom = 'OTU:MEAS:CURS?';
+    /**
+     * Get the SOM and EOM of the measurement on demand
+     *
+     * @return string
+     */
+    static function getMeasurementCursors( )
+    {
+    	return self::CMD_meas_som_eom;
+    }
+    
     //****************
     //* Links
     //***************
@@ -1121,7 +1233,22 @@ class SMTOtuApi
     static function getLinkListPerPortCommand($portFrom, $portTo)
     {
     	return sprintf(self::CMD_link_list_per_port, $portFrom, $portTo);
-    }    
+    }
+
+    const CMD_links_ports = 'OTU:LINK:PORTs? %d, %d';
+    
+    /**
+     * links port per port range command
+     *
+     * @param number $portFrom
+     * @param number $portTo
+     *
+     * @return string
+     */
+    static function getLinkPortListPerPortCommand($portFrom, $portTo)
+    {
+    	return sprintf(self::CMD_links_ports, $portFrom, $portTo);
+    }
     
     const CMD_Virtual_Switch_Port_Count = 'OTU:VSW:PORT:COUNT?';
             
@@ -1346,11 +1473,11 @@ class SMTOtuApi
     const CMD_info_test_mon = 'OTU:MON:INF:DET? %d';
     
     /**
-     * Symetric to OTU:TOPAZ:MON:Add command
+     * Symetric to OTU:TOPAZ:MON:PEAK:Add command
      * 
      * @param number $testId     
      */
-    const CMD_test_mon_desc = 'OTU:TOPAZ:MON:PEAK:GET? %d';
+    const CMD_test_mon_desc = 'OTU:HIGHSENS:MON:GET? %d';
     /**
      * Get test description command
      *
@@ -1377,7 +1504,7 @@ class SMTOtuApi
     static function getTestAvailableCommand( $testId )
     {
     	return sprintf( self::CMD_test_mon_available, $testId );
-    }    
+    }
     
     /**
      * testId//availability [KO, OK]
@@ -1396,6 +1523,23 @@ class SMTOtuApi
     	return sprintf( self::CMD_set_test_mon_available, $testId, $available);
     }
     
+    /**
+     * testId
+     */
+    const CMD_test_mon_info = 'OTU:TOPAZ:MON:INFO? %d';
+    
+    /**
+     * Get test mode and available/ not available command
+     *
+     * @param number $testId
+     *
+     * @return string
+     */
+    static function getTestInfoCommand( $testId )
+    {
+    	return sprintf( self::CMD_test_mon_info, $testId );
+    }
+    
     /**
      *  [STOP, SEQU, RAND]
      */
@@ -1425,8 +1569,39 @@ class SMTOtuApi
     {
     	return sprintf(self::CMD_set_mon_seq_status, $status );
     }
-        
-        
+    
+    
+    
+    /**
+     *  [WAIT, ENABLE, DISABLE]
+     */
+    const CMD_get_mon_seq_suspend = 'OTU:SUSPEND?';
+    
+    /**
+     * Get monitoring sequensor suspend status command
+     *
+     * @return string [WAIT, ENABLE, DISABLE]
+     */
+    static function getMonitoringSequensorSuspend()
+    {
+    	return self::CMD_get_mon_seq_suspend;
+    }
+    
+    /**
+     *  [WAIT, ENABLE, DISABLE]
+     */
+    const CMD_set_mon_seq_suspend = 'OTU:SUSPEND %s';
+    
+    /**
+     * Set monitoring sequensor suspend status 
+     *
+     * @param boolean
+     */
+    static function setMonitoringSequensorSuspend( $suspend )
+    {
+    	return sprintf(self::CMD_set_mon_seq_suspend, $suspend? self::RES_ENABLE : self::RES_DISABLE);
+    }
+    
     /**
      * testId
      */    
@@ -1496,6 +1671,63 @@ class SMTOtuApi
     	return sprintf( self::CMD_test_add, 0, 0, $linkId, self::RES_OK, self::RES_NO, $traceOtdrName, $firstMakerM, $lastMarkerM, $peakShift, $monitoringType, $thresholdsCount, $thresholdsBuffer, $peaksPositionsBuffer,$peakNames);
     }
     
+    /**
+     * test start date(s)// period mn// linkId// test available [KO, OK]// loc always after (NO, ONELoc, ALLLoc])// trace name // test mode // first marker m// last marker m// peak shift en point// type monitoring de pic// number of thresholds //threshold buffer// peaks positions buffer // peak names
+     *
+     * @return testId
+     */
+    const CMD_highsens_test_add = 'OTU:HIGHSENS:MON:ADD? %d,%d,%d,%s,%s,"%s",%s,%.2F,%.2F,%.2F,%s,%s,%s,%d,%s,%s,%s,%d,"%s"';
+    /**
+     * Build add test command
+     *
+     * @param integer $linkId
+     * @param string $traceOtdrName
+     * @param float $SOM
+     * @param float $EOM
+     * @param int $peakShift
+     * @param string $peakMonitoringType
+     * @param integer $peakCount
+     * @param string $thresholdsBuffer
+     * @param string $peaksThresholdsBuffer
+     * @param string $peaksPositionsBuffer
+     * @parma string $peakNames
+     *
+     * @return string
+     */
+    static function addHighsensTestCommand( $linkId, $testMode, $traceOtdrName, $SOM, $EOM, $peakShift, $peakMonitoringType, $peakCount, $thresholdsBuffer, $peaksThresholdsBuffer, $peaksPositionsBuffer, $peakNames)
+    {
+    	return sprintf( self::CMD_highsens_test_add, 0, 0, $linkId, self::RES_OK, self::RES_NO, $traceOtdrName, $testMode, $SOM, $SOM, $EOM, $thresholdsBuffer, self::EMPTY_BUFFER,self::EMPTY_BUFFER,$peakCount,$peaksThresholdsBuffer,$peaksPositionsBuffer,$peakMonitoringType,$peakShift,$peakNames);
+    }
+    
+    /**
+     * test Id, test start date(s)// period mn// linkId// test available [KO, OK]// loc always after (NO, ONELoc, ALLLoc])// trace name // first marker m// last marker m// peak shift en point// type monitoring de pic// number of thresholds //threshold buffer// peaks positions buffer // peak names
+     *
+     * @return testId
+     */
+    const CMD_highsens_test_update = 'OTU:HIGHSENS:MON:CHAN %d,%d,%d,%d,%s,%s,"%s",%.2F,%.2F,%.2F,%s,%s,%s,%d,%s,%s,%s,%d,"%s"';
+    /**
+     * Build change test command
+     *
+     * @param integer $testId
+     * @param integer $linkId
+     * @param string $traceOtdrName
+     * @param float $SOM
+     * @param float $EOM
+     * @param int $peakShift
+     * @param string $peakMonitoringType
+     * @param integer $peakCount
+     * @param string $thresholdsBuffer
+     * @param string $peaksThresholdsBuffer
+     * @param string $peaksPositionsBuffer
+     * @parma string $peakNames
+     *
+     * @return string
+     */
+    static function updateHighsensTestCommand( $testId, $linkId, $traceOtdrName, $SOM, $EOM, $peakShift, $peakMonitoringType, $peakCount, $thresholdsBuffer, $peaksThresholdsBuffer, $peaksPositionsBuffer, $peakNames)
+    {
+    	return sprintf( self::CMD_highsens_test_update, $testId,0, 0, $linkId, self::RES_OK, self::RES_NO, $traceOtdrName, $SOM, $SOM, $EOM, $thresholdsBuffer, self::EMPTY_BUFFER,self::EMPTY_BUFFER,$peakCount,$peaksThresholdsBuffer,$peaksPositionsBuffer,$peakMonitoringType,$peakShift,$peakNames);
+    }
+    
     /**
      * add test localisation:
      * testId// startOfMonitoring m// buffer start of monitoring threshold// peak shift en point// trace name1// start of trace zone1// trace name2// start of trace zone2// trace 3// start of trace zone3// number of peaks //peaks threshold buffer// peaks positions buffer
@@ -1911,7 +2143,6 @@ class SMTOtuApi
     	return sprintf( self::CMD_GET_MONITORING_TEST_PORT, $testId);
     }
     
-    
     const CMD_SET_FIREWALL = "OTU:SYSTEM:FIREWALL %s";
     const CMD_GET_FIREWALL = "OTU:SYSTEM:FIREWALL?";
     
@@ -2061,6 +2292,36 @@ class SMTOtuApi
     	return sprintf(self::CMD_otu_is_option_status, SMTLicenseList::OTU_OPTION_SAA_L2_MONITORING);
     } 
     
+    /**
+     * OTU COMMAND
+     *
+     * @return string //IMPOSSIBLE POSSIBLE AVAILABLE EXPIRED
+     */
+    static function isOtu_Tapping_Monitoring_Option()
+    {
+    	return sprintf(self::CMD_otu_is_option_status, SMTLicenseList::OTU_OPTION_TAPPING_MONITORING);
+    } 
+    
+    /**
+     * OTU COMMAND
+     *
+     * @return string //IMPOSSIBLE POSSIBLE AVAILABLE EXPIRED
+     */
+    static function isOtu_Light_Source_Option()
+    {
+    	return sprintf(self::CMD_otu_is_option_status, SMTLicenseList::OTU_OPTION_LIGHT_SOURCE);
+    }
+    
+    /**
+     * OTU COMMAND
+     *
+     * @return string //IMPOSSIBLE POSSIBLE AVAILABLE EXPIRED
+     */
+    static function isOtu_Rest_Api_Option()
+    {
+    	return sprintf(self::CMD_otu_is_option_status, SMTLicenseList::OTU_OPTION_REST_API);
+    }
+    
     /**
      * WARNING ISU COMMANDS
      * WARNING ISU COMMANDS
@@ -2136,6 +2397,16 @@ class SMTOtuApi
     	return sprintf(self::CMD_isu_is_license_status, SMTLicenseList::PEAK_MON);
     } 
     
+    /**
+     * WARNING ISU COMMAND
+     *
+     * @return string //VALID or INVALID
+     */
+    static function isTapping_Monitoring_Option()
+    {
+    	return sprintf(self::CMD_isu_is_license_status, SMTLicenseList::PEAK_MON);
+    } 
+    
     const CMD_isu_license_import = "ISU:LIC:IMPORT DISK, \"%s\"";
     
     /**
@@ -2157,7 +2428,7 @@ class SMTOtuApi
     const CMD_is_Backup_Hard_Disk_Option = 'OTU:HDBackup:OPTion?';
     static function get_is_Backup_Hard_Disk_Option()
     {
-    	return self::CMD_get_harddisk_status;
+    	return self::CMD_is_Backup_Hard_Disk_Option;
     }
     const CMD_reset_harddisk = 'OTU:HDISK:RESET';
     static function get_reset_harddisk()
@@ -2166,11 +2437,142 @@ class SMTOtuApi
     }
     
     // ssh strong/weak
-    const CMD_Get_Ssh_Personalization='OTU:SYST:COM:SSH?';    
+    const CMD_Get_Ssh_Personalization='OTU:SYST:COM:SSH?';
     static function getSsh_Personalization()
     {
     	return self::CMD_Get_Ssh_Personalization;
     }        
+    
+    const CMD_get_otu_mon_mode= 'OTU:TOPAZ:MON:MODe?';
+    function get_otu_mon_mode()
+    {
+    	return self::CMD_get_otu_mon_mode;
+    }
+    
+    const CMD_set_otu_mon_mode= "OTU:TOPAZ:MON:MODe %s";
+    function set_otu_mon_mode($mode)
+    {
+    	return sprintf( self::CMD_set_otu_mon_mode, $mode);
+    }
+    
+    ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+    //
+    // API
+    //
+    ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+    
+    const CMD_Api_get_otu_Main_INFO= 'OTU:API:CONF:SUMary?';
+    /**
+     * @return string "04993","OTU 8000E","OTDR","4","1561628574","PEAK_MON SMART_ACCESS_ANYWHERE","V18.05"
+     */
+    static function getOtuMainInfo()
+    {
+    	return self::CMD_Api_get_otu_Main_INFO;
+    }
+    
+    const CMD_Api_update_otu_date = "OTU:API:CONF:DATE %d";
+    static function updateOtuDate($timestamp)
+    {
+    	return sprintf(self::CMD_Api_update_otu_date, $timestamp);
+    }
+    
+    const CMD_Api_setSnmpConfig = "OTU:API:CONF:SNMP:CONF %d,\"%s\",\"%s\",%s";
+    static function setSnmpConfig($id, $address, $community, $port)
+    {
+    	return sprintf(self::CMD_Api_setSnmpConfig, $id, $address, $community, $port);
+    }
+    
+    const CMD_Api_getSnmpConfig = "OTU:API:CONF:SNMP:CONF? %d";
+    static function getSnmpConfig($id)
+    {
+    	return sprintf(self::CMD_Api_getSnmpConfig, $id);
+    }
+    
+    const CMD_Api_setSnmpImAlive = "OTU:API:CONF:SNMP:IMAlive %d";
+    static function setSnmpImAlive($periodMin)
+    {
+    	return sprintf(self::CMD_Api_setSnmpImAlive, $periodMin);
+    }
+    
+    const CMD_Api_getSnmpImAlive = 'OTU:API:CONF:SNMP:IMAlive?';
+    static function getSnmpImAlive()
+    {
+    	return self::CMD_Api_getSnmpImAlive;
+    }    
+    
+    const CMD_Api_testSnmpConfig = "OTU:API:CONF:SNMP:TEST %d";
+    static function testSnmpConfig($id)
+    {
+    	return sprintf(self::CMD_Api_testSnmpConfig, $id);
+    }
+    
+    const CMD_Api_getPort = "OTU:API:PORT:CONF? %d";
+    static function getPortConfig($port)
+    {
+    	return sprintf(self::CMD_Api_getPort, $port);
+    }
+    
+    const CMD_Api_updatePort = "OTU:API:PORT:CONF %d,\"%s\",%s";
+    static function updatePortConfig($port, $name, $monitored)
+    {
+    	return sprintf(self::CMD_Api_updatePort, $port, $name, $monitored? 'TRUE' : 'FALSE');
+    }
+    const CMD_Api_getModule_Info = 'OTU:API:CONF:MOD:OPT?';
+    static function getModuleInfo()
+    {
+    	return self::CMD_Api_getModule_Info;
+    }
+    const CMD_Api_getIpv4 = 'OTU:API:CONF:ETH:IPV4?';
+    static function getIpv4Config()
+    {
+    	return self::CMD_Api_getIpv4;
+    }
+    const CMD_Api_getIpv6 = 'OTU:API:CONF:ETH:IPV6?';
+    static function getIpv6Config()
+    {
+    	return self::CMD_Api_getIpv6;
+    }
+    const CMD_Api_getPortAlarmStatus = "OTU:API:ALARM:OPT:GET? %d";
+    static function getPortAlarmStatus($port)
+    {
+    	return sprintf(self::CMD_Api_getPortAlarmStatus, $port);
+    }
+    
+    const CMD_Api_getReplayAlarm = "OTU:API:ALARM:OPT:REPLAY %d";
+    static function replayAlarm($port)
+    {
+    	return sprintf(self::CMD_Api_getReplayAlarm, $port);
+    }
+    
+    const CMD_Api_getClearAlarm = "OTU:API:ALARM:OPT:CLEAR %d";
+    static function clearAlarm($port)
+    {
+    	return sprintf(self::CMD_Api_getClearAlarm, $port);
+    }
+    
+    const CMD_Api_getClearAllAlarms = "OTU:API:ALARM:CLRALL";
+    static function clearAllAlarms()
+    {
+    	return self::CMD_Api_getClearAllAlarms;
+    }
+    
+    const CMD_Api_getToken = "OTU:API:TOKEN?";
+    static function getApiToken()
+    {
+    	return self::CMD_Api_getToken;
+    }
+    
+    const CMD_Api_checkToken = "OTU:API:TOKEN \"%s\"";
+    static function getApiCheckToken($token)
+    {
+    	return sprintf(self::CMD_Api_checkToken, $token);
+    }
+    
+    const CMD_Api_changeSmartOTUCredential= "OTU:API:USER:SMARTOTU \"%s\",\"%s\",\"%s\",\"%s\"";
+    static function changeSmartOTUCredential($currentLogin, $currentPassword, $newLogin, $newPassword)
+    {
+    	return sprintf(self::CMD_Api_changeSmartOTUCredential, $currentLogin, $currentPassword, $newLogin, $newPassword);
+    }
 }
 
 
