@@ -174,7 +174,9 @@ class SMTOtuSocket
      *
      * @var int LONG TIME OUT FOR READING RESPONSE IN SOCKET : 300s
      */
-    const LONG_TIME_OUT_READING = 300;    
+    const LONG_TIME_OUT_READING = 300;
+    
+    const LONGER_TIME_OUT_READING = 90;
     
     /**
      * bloc size of data read in socket stream
@@ -504,7 +506,7 @@ class SMTOtuSocket
      * 
      * @param string $query query string
      * @param number $sleep (in microseconds) sleep before starting to retrieve the answer
-     * @param string $readTimeOut (in s) wait until $readTimeOut for the ESR status
+     * @param number $readTimeOut (in s) wait until $readTimeOut for the ESR status
      * @param string $removeQuotes TRUE by default: remove double quotes from returned string
      *
      * @return The result of the query.
