@@ -1,11 +1,13 @@
 <?php
 define("MSG_BAD_CREDENTIALS","The supplied credentials (login or password) are invalid.");
 define("MSG_BAD_THRESHOLD_VALUE","Invalid threshold value %s for field: %s");
-define("MSG_CHINESE","Chinese");
+define("MSG_BAD_ROTAU_IP","Cannot connect to ROTAU with Ip address %s");
+define("MSG_CHINESE","中文");
 define("MSG_CONNECTION","Connect");
 define("MSG_COPYRIGHT_SHORT","Copyright © 2019 VIAVI. All rights reserved.");
 define("MSG_ENGLISH","English");
 define("MSG_ERROR_ADD_LOCALISATION_ERROR","Add localisation error"); 
+define("MSG_ERROR_ALARM_UNDEFINED","Undefined alarm");
 define("MSG_ERROR_ALARM_FETCH_FAILED","Failed to retrieve alarm: ");
 define("MSG_ERROR_APPLY_DATABASE_PATCH_FAILURE","Failed to apply database patches!");
 define("MSG_ERROR_CLEAR_TEST_ALARM","Failed to remove the test alarms!");
@@ -142,7 +144,7 @@ define("MSG_ERROR_WRONG_LASER","Wrong Laser");
 define("MSG_ERROR_WRONG_PULSE","Wrong Pulse"); 
 define("MSG_ERROR_WRONG_RANGE","Wrong Range!"); 
 define("MSG_ERROR_WRONG_RES","Wrong Resolution"); 
-define("MSG_FRENCH","French");
+define("MSG_FRENCH","Français");
 define("MSG_INVALID_LOG_LEVEL_PARAMETER","Invalid log level parameter, should be: %s");
 define("MSG_INVALID_VALUE_EXCEPTION","Invalid value for parameter: %s");
 define("MSG_INVALID_STATUS","Invalid status for the operation!");
@@ -229,6 +231,7 @@ define("OTU_SYST_ALARM_POWER_FAILURE","Power failure");
 define("PEAK","Peak");
 define("PERSISTENT_FAILURE","Persistent failure");
 define("PON_FAILURE","Pon test failure");
+define("OTU_SYST_REFERENCE_DRIFT_FAILURE","Reference trace drift");
 define("RAMAN_POWER_DETECTION","RAMAN power detection");
 define("RAMAN_POWER_DECREASE","RAMAN power decreased");
 define("REBOOT","Reboot");
@@ -241,6 +244,9 @@ define("TEMPORARY_PROBLEM","Temporary problem");
 define("TEST_MEDIA","Media test");
 define("TIMEOUT_ON_MONITORING_TEST_CYCLE","Timeout on monitoring cycle");
 define("THRESHOLD_LEVEL_EXCEEDED","Threshold crossed");
+define("CONNECTOR_FAILURE","Connector");
+define("CONNECTOR_FIBER_CUT_FAILURE","Fiber Cut (Connector)");
+define("CONNECTOR_ATTENUATION_FAILURE","Attenuation (Connector)");
 define("UNKNOW_ALARM","Unknown alarm");
 define("UNKNOWN_CAUSE","Unknown cause");
 ?>
