@@ -43,6 +43,8 @@ use app\util\SMTLogger;
 use app\util\SMTUtil;
 use app\view\SMTFileDownloadPage;
 use app\view\SMTTestRestApiPage;
+use app\serviceshelper\monitoring\SMTTestMode;
+use app\admin\SMTOtuMonitoringOptions;
 /**
  * Service to setup and list link-tests.
  * For smartOTU: link = test but linkId != testId
@@ -64,6 +66,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
         $linkId = -1;
         $linkHelper = new SMTLinkTest();
         $linkHelper->setContext( $this->getContext() );
+        $linkExists = FALSE;
         
         try
         {
@@ -84,13 +87,21 @@ class SMTLinkTestService extends SMTService implements SMTIService
                     }
                     else
                     {
-                    	throw new SMTLinkTestException( SMTLinkTestException::ERROR_LINK_ALREADY_EXIST, sprintf("Link already exists on link %s!", $linkTestDto->getId() ) );
-                    }                
+                    	$linkId = $linkTestDto->getId();
+                    	$linkExists = TRUE;
+//                     	throw new SMTLinkTestException( SMTLinkTestException::ERROR_LINK_ALREADY_EXIST, sprintf("Link already exists on link %s!", $linkTestDto->getId() ) );
+                    }
                 }
                 
                 //test if no test is already present on link
                 if ( !$linkHelper->hasTest( $linkTestDto->getId() ) )
                 {
+                	if ( $linkExists )
+                	{
+                		$linkHelper->deleteLink( $linkId );
+                		$linkTestDto->resetId();
+                		$linkId = $linkHelper->createLink( $linkTestDto );
+                	}
             	    $testId = $linkHelper->createTest( $linkTestDto );
             	    
             	    //if monitoring and measure is allowed force sequencer on
@@ -171,10 +182,11 @@ class SMTLinkTestService extends SMTService implements SMTIService
             	
                 //update the test parameters on OTU if they have changed
                 $testDetail =$linkTestDto->getTestDetail(); 
+                SMTLogger::getInstance()->trace( "Test parameters new check sum: ".$testDetail->getCheckSum() ." old: ".$testDetail->computeObjectDtoCheckSum(), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
                 if ( $testDetail != NULL && $testDetail->hasChanged() )
                 {
                     SMTLogger::getInstance()->trace( "Test parameters have changed, update it.", SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
-            	    $otdrTraceFileReplaced = $linkHelper->updateTestParameters( $linkTestDto );
+                    $otdrTraceFileReplaced = $linkHelper->updateTest( $linkTestDto );
                 }
                 
                 //if monitoring and measure are allowed and monitoring was not allowed before, 
@@ -550,7 +562,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
     		{
     		    if ( SMTLinkTest::checkLinkTestId( $linkId, FALSE) )
     		    {
-        		    $linkTestDto = $linkHelper->retrieveLinkTest( $linkId, $sequensorOn, $portCount );    		    
+        		    $linkTestDto = $linkHelper->retrieveLinkTest( $linkId, $sequensorOn, $portCount );
         		    if ( $linkTestDto != NULL )
         		    {
         		        $linkTestListDto->addLinkTest( $linkTestDto );
@@ -666,7 +678,10 @@ class SMTLinkTestService extends SMTService implements SMTIService
     		$alarmHelper = new SMTAlarm();
     		$alarmHelper->setContext( $this->getContext() );
     		$alarmHelper->deleteOpticalAlarmOnOtu( $testId );
-    		$alarmHelper->deleteAllPeakAlarmOnOtu( $testId );
+    		if ( SMTLinkTest::getPeakCount($this->getContext()->getOtuSocket(), $testId) > 0 )
+    		{
+    			$alarmHelper->deleteAllPeakAlarmOnOtu( $testId );
+    		}
     		//don't clear the alarm on smartOTU, wait for the clear comming from OTU
 //     		$alarmHelper->deleteOpticalAlarmOnSmartOtu( $testId );
     		
@@ -851,6 +866,30 @@ class SMTLinkTestService extends SMTService implements SMTIService
     	return $linkDto->getJsonData();
     }
     
+    /**
+     * Fetch link test info
+     * portid = port identifier
+     *
+     * @url GET /port/{portid}
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function fetchLinkTestByPort( $portid )
+    {
+    	try
+    	{
+    		//retrieve links ids
+    		$linkId = $this->sendReceive( SMTOtuApi::getLinkListPerPortCommand($portid, $portid) );
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    	
+    	return $this->fetchLinkTest($linkId);
+    }
+    
     /**
      * Fetch link test with its test detail info if it exists
      * id = link identifier
@@ -873,8 +912,17 @@ class SMTLinkTestService extends SMTService implements SMTIService
     		//don't crash if we don't have any test
     		if ( $linkDto->getTestId() !== NULL )
     		{
-        		$linkTestDetailDto = $linkHelper->retrieveLinkTestDetail( $linkDto->getTestId() );
-        		$linkDto->setTestDetail( $linkTestDetailDto );
+    			//don't crash if the test type is unknown (DTSS for example); we ignore it
+    			try 
+    			{
+        			$linkTestDetailDto = $linkHelper->retrieveLinkTestDetail( $linkDto->getTestId() );
+        			$linkDto->setTestDetail( $linkTestDetailDto );
+    			}
+    			catch(\Exception $ex)
+    			{
+    				$linkDto->resetTestId( );
+    				$this->getContext()->getLogger()->traceException( $e );
+    			}
     		}
     	}
     	catch ( \Exception $e )
@@ -885,7 +933,27 @@ class SMTLinkTestService extends SMTService implements SMTIService
     	return $linkDto->getJsonData();
     }    
     
-    
+    /**
+     * Fetch link test with its test detail info if it exists
+     *
+     * @url GET /port/{portid}/detail
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function fetchLinkTestDetailByPort( $portid )
+    {
+    	try
+    	{
+    		$linkId = $this->sendReceive( SMTOtuApi::getLinkListPerPortCommand($portid, $portid) );
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    	
+    	return $this->fetchLinkTestDetail($linkId);
+    }
     
     /**
      * Fetch test detail info
@@ -918,7 +986,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * Fetch test detail info
      * portid = port identifier
      *
-     * @url GET /port/{portid}
+     * @url GET /test/port/{portid}
      *
      * @access protected
      * @class SMTAccessControl {@requires user}
@@ -983,14 +1051,16 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * @access protected
      * @class SMTAccessControl {@requires user}
      */
-    function initTestDetail( $id )
+    function initTestDetail( $id, $request_data)
     {
     	try
     	{
+    		$mode = ($request_data != NULL && $request_data['mode'] != NULL)? $request_data['mode'] : SMTTestMode::HIGHSENS;
+    		
     		$linkHelper = new SMTLinkTest();
     		$linkHelper->setContext( $this->getContext() );
     
-    		$linkDto = $linkHelper->initLinkTest( $id, NULL, NULL);
+    		$linkDto = $linkHelper->initLinkTest( $id, NULL, NULL, $mode);
     	}
     	catch ( \Exception $e )
     	{
@@ -1012,7 +1082,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * @access protected
      * @class SMTAccessControl {@requires user}
      */
-    function initTestByPort($portid)
+    function initTestByPort($portid, $request_data)
     {
         try
         {
@@ -1038,15 +1108,17 @@ class SMTLinkTestService extends SMTService implements SMTIService
         		    }        		    
         		}
         		else
-        		{  		    
-        		    $linkDto = $linkHelper->initLinkTest( $linkId, NULL, NULL);
+        		{
+        			$mode = ($request_data != NULL && $request_data['mode'] != NULL)? $request_data['mode'] : SMTTestMode::HIGHSENS;
+        			$linkDto = $linkHelper->initLinkTest( $linkId, NULL, NULL, $mode);
         		}
         	}
         	else
         	{
+        		$mode = ($request_data != NULL && $request_data['mode'] != NULL)? $request_data['mode'] : SMTTestMode::HIGHSENS;
         	    //retrieve the module running number:
         	    $moduleRunningNumber = $linkHelper->getModuleRunningNumber();
-        	    $linkDto = $linkHelper->initLinkTest( NULL, $portid, $moduleRunningNumber);
+        	    $linkDto = $linkHelper->initLinkTest( NULL, $portid, $moduleRunningNumber, $mode);
         	}
         }
         catch ( \Exception $e )
@@ -1090,6 +1162,8 @@ class SMTLinkTestService extends SMTService implements SMTIService
     		        $this->getContext()->getLogger()->traceException($ex);
     		    }
     		}
+    		//remove old gps file
+    		SMTGpsRoute::removeOldKmlFileName($id);
     		$kmlHelper->processKml($filename, $id);
     		    		
 			$linkDto = $linkHelper->retrieveLinkTest( $id );
@@ -1239,7 +1313,30 @@ class SMTLinkTestService extends SMTService implements SMTIService
     	return $dto->getJsonData();
     }
     
-    
+    /**
+     * Set monitoring mode
+     *
+     * @url POST /mode/{mode}
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function setOtuLegacyMonitoringMode($mode)
+    {
+    	try
+    	{
+    		$this->send( SMTOtuApi::set_otu_mon_mode( $mode ) );
+    		
+    		//update and force retrieval of monitoring options
+    		$monitoringOptions = SMTOtuMonitoringOptions::getOtuMonitoringOptions($this->getContext(), TRUE);
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    	
+    	return array('option',$monitoringOptions);
+    }
     
     /**
      * Create all links
