@@ -56,6 +56,9 @@ use app\services\security\SMTAccessControl;
 use app\parser\SMTOtuApi;
 use app\serviceshelper\monitoring\SMTLinkTestException;
 use app\serviceshelper\alarm\SMTAlarmFactory;
+use app\serviceshelper\otdr\SMTBaseOtdrTraceFileUtil;
+use app\serviceshelper\otdr\SMTTraceFileType;
+use app\serviceshelper\monitoring\SMTTestMode;
 
 /**
  * Service to setup and list link-tests.
@@ -264,6 +267,8 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
      */
     function getAcquisitionTrace( $operationId )
     {
+    	$SOM = 0;
+    	$EOM = 0;
         try 
         {
             if ( SMTOperationManager::hasOperation( $operationId ) )
@@ -273,14 +278,18 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
                 {
                 	if ( SMTOperationEventDto::isResultAvailable( $measureCache->getStatus() ) );
                 	{
-                	    $traceFilePath = $measureCache->getTraceDirectory()."/".$measureCache->getTraceName();                	    
+                		$traceFilePath = $measureCache->getTraceDirectory()."/".$measureCache->getTraceName();   
+                		$traceFilePath = SMTBaseOtdrTraceFileUtil::replaceExtension($traceFilePath, SMTBaseOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION);
+                		
                 	    SMTLogger::getInstance()->trace( sprintf("Acquisition trace %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
                 	    
                 	    $portNumber = $measureCache->getPortId();
+                	    $SOM = $measureCache->getSOM();
+                	    $EOM = $measureCache->getEOM();
                 	}
                 }            
                 //remove operation from cache
-                SMTOperationManager::deleteMeasureInfo($operationId);            
+                SMTOperationManager::deleteMeasureInfo($operationId);
             }
         
             if ( !isset($traceFilePath) )
@@ -290,11 +299,24 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
             
         	//backup OTDR file to the smartOTU directory to be used for monitoring test addition
         	$newFilePath = SMTSessionDirectoryUtil::backupOTDRTraceToSessionDirectory( $traceFilePath, $portNumber, $operationId );
-        
-        	SMTLogger::getInstance()->trace( sprintf("Acquisition backup trace in SmartOtu %s ",  $newFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
-        	
-        	$page = new SMTOtdrTracePage( $newFilePath, SMTOtdrTraceType::SMARTOTU_ACQUISITION_TRACE );
-        	
+        	SMTLogger::getInstance()->trace( sprintf("Acquisition backup trace in SmartOtu %s ",  $newFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);        	
+        	        	
+        	$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
+        	// if smart acq
+        	$smartAcq = SMTBaseOtdrTraceFileUtil::isSmartAcqFileExtension($smartAcqTraceExtension);
+        	if ( $smartAcq )
+        	{
+        		$smartAcqTraceFilePath = SMTBaseOtdrTraceFileUtil::replaceExtension($traceFilePath, $smartAcqTraceExtension);
+        		SMTLogger::getInstance()->trace( sprintf("smartAcqTraceFilePath Acquisition backup trace in SmartOtu %s ",  $smartAcqTraceFilePath), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+        		//backup smart acq file to the smartOTU directory to be used for monitoring test addition
+        		$shortAcqNewFilePath = SMTSessionDirectoryUtil::backupOTDRTraceToSessionDirectory( $smartAcqTraceFilePath, $portNumber, $operationId, TRUE );
+        		SMTLogger::getInstance()->trace( sprintf("SmartAcq Acquisition backup trace in SmartOtu %s ",  $shortAcqNewFilePath), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+        		$page = new SMTOtdrTracePage( $shortAcqNewFilePath, SMTOtdrTraceType::SMARTOTU_ACQUISITION_TRACE, SMTTraceFileType::getFileType($shortAcqNewFilePath), $smartAcq, $SOM, $EOM );
+        	}
+        	else
+        	{
+        		$page = new SMTOtdrTracePage( $newFilePath, SMTOtdrTraceType::SMARTOTU_ACQUISITION_TRACE, SMTTraceFileType::getFileType($newFilePath), $smartAcq, $SOM, $EOM );
+        	}
         	$this->getContext()->getHttpResponse()->send( $page );
     	}
     	catch ( \Exception $e )
@@ -305,7 +327,8 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     
     /**
      * Retrieve OTDR monitoring reference trace by its testId
-     *
+     * Warning: if a sliding reference exists, return it
+     *          if the reference is requested to be displayed with a last test acquisition: display short and long acq ( smartAcq = TRUE ) only if the last test acquisition is a localisation or if it's a tapping test 
      * //param testId The test with the monitoring reference trace
      *
      * @url POST /referencetrace/{testId}
@@ -313,23 +336,54 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
      * @access protected
      * @class SMTAccessControl {@requires user}
      */
-    function getMonitoringReferenceTrace( $testId )
+    function getMonitoringReferenceTrace( $testId,$request_data)
     {
+    	$slidingReferenceNotFound= TRUE;
+    	$hasAcquisitionLoc = FALSE;
+    	$tapping = FALSE;
+    	$SOM = 0;
+    	$EOM = 0;
+    	
         try 
         {
+        	$slidingReference = ($request_data != NULL && $request_data['sliding'] != NULL)? filter_var( $request_data['sliding'], FILTER_VALIDATE_BOOLEAN ) : FALSE;
+        	$lastAcquisition = ($request_data != NULL && $request_data['lastAcquisition'] != NULL)? filter_var( $request_data['lastAcquisition'], FILTER_VALIDATE_BOOLEAN ) : FALSE;
+        	
             //retrieve OTDR trace name
             SMTLinkTest::checkTestId($testId);
             	
             $linkHelper = new SMTLinkTest();
             $linkHelper->setContext( $this->getContext() );
             $linkTestDetailDto = $linkHelper->retrieveLinkTestDetail( $testId );
+            $tapping = SMTTestMode::isTappingMode( $linkTestDetailDto->getTestMode());
             $traceName = $linkTestDetailDto->getOtdrTraceName();
+            $SOM = $linkTestDetailDto->getFirstMarkerDistanceM();
+            $EOM = $linkTestDetailDto->getLastMarkerDistanceM();
         
-        	$traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR.SMTOtdrTraceFileUtil::checkSorFileExtension( $traceName );
+            //check if sliding reference exists
+            if ( $slidingReference )
+            {
+            	$traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_SLIDING_DIR.SMTOtdrTraceFileUtil::checkSorFileExtension( $traceName );
+            	$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath, $slidingReferenceNotFound);
+            }
+            if ( !$slidingReference || $slidingReferenceNotFound )
+            {
+            	$traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR.SMTOtdrTraceFileUtil::checkSorFileExtension( $traceName );
+        		$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
+            }
+            
+            if ( !$tapping && $lastAcquisition )
+            {
+            	$portNumber = SMTLinkTest::getPortNumber($this->getContext()->getOtuSocket(), intval($testId));
+            	$hasAcquisitionLoc = SMTSessionDirectoryUtil::hasLastAcquisitionLocalisation(intval($testId), intval($portNumber));
+            }
         	
-        	SMTLogger::getInstance()->trace( sprintf("Retrieve otdr reference monitoring trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+            $smartAcq = SMTBaseOtdrTraceFileUtil::isSmartAcqFileExtension($smartAcqTraceExtension) && ($tapping || !$lastAcquisition || $hasAcquisitionLoc);
+            $traceFilePath= SMTBaseOtdrTraceFileUtil::replaceExtension($traceFilePath, $smartAcqTraceExtension);
+            
+            SMTLogger::getInstance()->trace( sprintf("Retrieve otdr reference monitoring trace file %s slidingReference %d lastAcquisition %d hasAcquisitionLoc %d",  $traceFilePath , $slidingReference, $lastAcquisition, $hasAcquisitionLoc), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
         	
-        	$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_REFERENCE_TRACE );
+        	$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_REFERENCE_TRACE, SMTTraceFileType::getFileType($traceFilePath), $smartAcq, $SOM, $EOM);
         	
         	$this->getContext()->getHttpResponse()->send( $page );
     	}    	
@@ -341,7 +395,9 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     
     /**
      * Retrieve OTDR monitoring reference trace by its testId and its name; if name is invalid, same as getMonitoringReferenceTrace()
-     *
+     * Warning: if a sliding reference exists, return it
+     *          if the reference is requested to be displayed with a last test acquisition: display short and long acq ( smartAcq = TRUE ) only if the last test acquisition is a localisation or if it's a tapping test 
+
      * //param testId The test with the monitoring reference trace
      * //param name The reference trace name: usefull when replacing the reference of a monitoring test and the new reference is not yet used by OTU monitoring.
      *  
@@ -350,29 +406,72 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
      * @access protected
      * @class SMTAccessControl {@requires user}
      */
-    function getMonitoringReferenceTraceByName( $testId, $traceName )
+    function getMonitoringReferenceTraceByName( $testId, $traceName,$request_data)
     {
         $traceFileFound = FALSE;
+        $slidingReferenceNotFound= TRUE;
+        $hasAcquisitionLoc = FALSE;
+        $tapping = FALSE;
+        $SOM = 0;
+        $EOM = 0;
+        
     	try
     	{
+    		$slidingReference = ($request_data != NULL && $request_data['sliding'] != NULL)? filter_var( $request_data['sliding'], FILTER_VALIDATE_BOOLEAN ) : FALSE;
+    		$lastAcquisition = ($request_data != NULL && $request_data['lastAcquisition'] != NULL)? filter_var( $request_data['lastAcquisition'], FILTER_VALIDATE_BOOLEAN ) : FALSE;    		
+    		
     		//retrieve OTDR trace name
     		SMTLinkTest::checkTestId($testId);
-    		     
-    		$traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR.SMTOtdrTraceFileUtil::checkSorFileExtension( $traceName );
+    		
+    		//check if sliding reference exists
+    		if ( $slidingReference )
+    		{
+    			$traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_SLIDING_DIR.SMTOtdrTraceFileUtil::checkSorFileExtension( $traceName );
+    			$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath, $slidingReferenceNotFound);
+    		}
+    		if ( !$slidingReference || $slidingReferenceNotFound )
+    		{
+    			$traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR.SMTOtdrTraceFileUtil::checkSorFileExtension( $traceName );
+    			$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
+    		}
     		 
+    		$linkHelper = new SMTLinkTest();
+    		$linkHelper->setContext( $this->getContext() );
+    		$linkTestDetailDto = $linkHelper->retrieveLinkTestDetail( $testId );
+    		$tapping = SMTTestMode::isTappingMode( $linkTestDetailDto->getTestMode());
+    		$SOM = $linkTestDetailDto->getFirstMarkerDistanceM();
+    		$EOM = $linkTestDetailDto->getLastMarkerDistanceM();
+    		
     		//if the file is not found, use the reference declared in OTU
     		if ( !file_exists( $traceFilePath ) )
-    		{    		    
-    		    $linkHelper = new SMTLinkTest();
-    		    $linkHelper->setContext( $this->getContext() );
-    		    $linkTestDetailDto = $linkHelper->retrieveLinkTestDetail( $testId );
+    		{
     		    $traceName = $linkTestDetailDto->getOtdrTraceName();
-
-    		    $traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR.SMTOtdrTraceFileUtil::checkSorFileExtension( $traceName );
+    		    
+    		    //check if sliding reference exists
+    		    if ( $slidingReference )
+    		    {
+    		    	$traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_SLIDING_DIR.SMTOtdrTraceFileUtil::checkSorFileExtension( $traceName );
+    		    	$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath, $slidingReferenceNotFound);
+    		    }
+    		    if ( !$slidingReference || $slidingReferenceNotFound )
+    		    {
+    		    	$traceFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR.SMTOtdrTraceFileUtil::checkSorFileExtension( $traceName );
+    		    	$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
+    		    }
     		}
     		
-		    SMTLogger::getInstance()->trace( sprintf("Retrieve otdr reference monitoring trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);    		 
-		    $page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_REFERENCE_TRACE );        		 
+    		if ( !$tapping && $lastAcquisition )
+    		{
+    			$portNumber = SMTLinkTest::getPortNumber($this->getContext()->getOtuSocket(), intval($testId));
+    			$hasAcquisitionLoc = SMTSessionDirectoryUtil::hasLastAcquisitionLocalisation(intval($testId), intval($portNumber));
+    		}
+    		
+    		$smartAcq = SMTBaseOtdrTraceFileUtil::isSmartAcqFileExtension($smartAcqTraceExtension) && ($tapping || !$lastAcquisition || $hasAcquisitionLoc);
+    		
+    		$traceFilePath= SMTBaseOtdrTraceFileUtil::replaceExtension($traceFilePath, $smartAcqTraceExtension);
+    		
+    		SMTLogger::getInstance()->trace( sprintf("Retrieve otdr reference monitoring trace file by name %s slidingReference %d lastAcquisition %d hasAcquisitionLoc %d",  $traceFilePath , $slidingReference, $lastAcquisition, $hasAcquisitionLoc), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+    		$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_REFERENCE_TRACE, SMTTraceFileType::getFileType($traceFilePath), $smartAcq, $SOM, $EOM);
 		    $this->getContext()->getHttpResponse()->send( $page );
     		
     	}
@@ -405,22 +504,51 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     		$alarmDto = $alarmHelper->fetchOpticalAlarmFromTest( $testId );
     		
     		if ( $alarmDto != NULL )
-    		{    		 
+    		{
     			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portNumber, $alarmDto->getDiscriminator() );
+    		    
+    		    $smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
+    		    $smartAcq = SMTBaseOtdrTraceFileUtil::isSmartAcqFileExtension($smartAcqTraceExtension);
+    		    $traceFilePath= SMTBaseOtdrTraceFileUtil::replaceExtension($traceFilePath, $smartAcqTraceExtension);
+    		    
     		    SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
-    		    $page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE );    		   
+    		    
+    		    $page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE, SMTTraceFileType::getFileType($traceFilePath), $smartAcq);
     		}
     		else
     		{
-    		    throw new SMTAlarmException( SMTAlarmException::ERROR_ALARM_RETRIEVAL_FAILED, "testId = ".$testId );
+    			$alarmsDtoList = $alarmHelper->fetchPeakAlarmFromTest($testId);
+    			
+    			if ( ($alarmsDtoList != NULL) && count($alarmsDtoList) > 0 )
+    			{
+    				foreach ( $alarmsDtoList as $alarmDto)
+    				{
+    					if ( $alarmDto!= NULL )
+    					{
+    						$alarmPeakByTestDiscriminator = SMTAlarmFactory::getDiscriminatorForOtdrTrace( $alarmDto->getTestId());
+    						
+    						$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portNumber, $alarmPeakByTestDiscriminator );
+    						$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
+    						$smartAcq = SMTBaseOtdrTraceFileUtil::isSmartAcqFileExtension($smartAcqTraceExtension);
+    						$traceFilePath= SMTBaseOtdrTraceFileUtil::replaceExtension($traceFilePath, $smartAcqTraceExtension);
+    						
+    						SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+    						$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE, SMTTraceFileType::getFileType($traceFilePath), $smartAcq);
+    						break;
+    					}
+    				}
+    			}
+	    		else
+	    		{
+	    		    throw new SMTAlarmException( SMTAlarmException::ERROR_ALARM_RETRIEVAL_FAILED, "testId = ".$testId );
+	    		}
     		}
-    		
-    		$this->getContext()->getHttpResponse()->send( $page );
+    	$this->getContext()->getHttpResponse()->send( $page );
     	}
     	catch ( \Exception $e )
     	{
     		$this->handleException($e);
-    	}        
+    	}
     }
     
     /**
@@ -451,7 +579,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     			if ( file_exists( $traceFilePath ) )
     			{
     			    SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
-    			    $page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_SHORTACQ_ALARM_TRACE );
+    			    $page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_SHORTACQ_ALARM_TRACE, false );
     			    $this->getContext()->getHttpResponse()->send( $page );
     			}
     		}
@@ -467,7 +595,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     }    
     
     /**
-     * Retrieve OTDR detection alarm trace on the given test if it exists
+     * Retrieve OTDR detection alarm trace on the given test if it exists (only sor file)
      *
      * //param testId The test with the alarm acquisition trace. (One attenuation alarm by test).
      *
@@ -483,7 +611,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     		//retrieve OTDR trace name
     		SMTLinkTest::checkTestId($testId);
     		$portNumber = SMTLinkTest::getPortNumber($this->getContext()->getOtuSocket(), intval($testId));
-    
+    		
     		$alarmHelper = new SMTAlarm();
     		$alarmHelper->setContext( $this->getContext() );
     		$alarmDto = $alarmHelper->fetchOpticalAlarmFromTest( $testId );
@@ -491,8 +619,12 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     		if ( $alarmDto != NULL )
     		{
     			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portNumber, $alarmDto->getDiscriminator(), FALSE );
+    			$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
+    			$smartAcq = SMTBaseOtdrTraceFileUtil::isSmartAcqFileExtension($smartAcqTraceExtension);
+    			$traceFilePath= SMTBaseOtdrTraceFileUtil::replaceExtension($traceFilePath, $smartAcqTraceExtension);
+    			
     			SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
-    			$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE );
+    			$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE, SMTTraceFileType::getFileType($traceFilePath), $smartAcq);
     		}
     		else
     		{
@@ -507,8 +639,12 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
 	    					$alarmPeakByTestDiscriminator = SMTAlarmFactory::getDiscriminatorForOtdrTrace( $alarmDto->getTestId());
 	    					
 	    					$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portNumber, $alarmPeakByTestDiscriminator, FALSE );
+	    					$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
+	    					$smartAcq = SMTBaseOtdrTraceFileUtil::isSmartAcqFileExtension($smartAcqTraceExtension);
+	    					$traceFilePath= SMTBaseOtdrTraceFileUtil::replaceExtension($traceFilePath, $smartAcqTraceExtension);
+	    					
 	    					SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
-	    					$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE );
+	    					$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE, SMTTraceFileType::getFileType($traceFilePath), $smartAcq);
 	    					break;
 	    				}
 	    			}
@@ -539,16 +675,29 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
      */
     function getLastMonitoringAcquisitionTrace( $testId )
     {
+    	$SOM = 0;
+    	$EOM = 0;
+    	$isLoc = FALSE;
+    	
     	try
     	{
     		//retrieve OTDR trace name
     		SMTLinkTest::checkTestId($testId);
+    		
+    		$linkHelper = new SMTLinkTest();
+    		$linkHelper->setContext( $this->getContext() );
+    		$linkTestDetailDto = $linkHelper->retrieveLinkTestDetail( $testId );
+    		$SOM = $linkTestDetailDto->getFirstMarkerDistanceM();
+    		$EOM = $linkTestDetailDto->getLastMarkerDistanceM();
+    		
     		$portNumber = SMTLinkTest::getPortNumber($this->getContext()->getOtuSocket(), intval($testId));
-    		$traceFilePath = SMTOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId, $portNumber );
+    		$traceFilePath = SMTBaseOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId, $portNumber, $isLoc, TRUE);
+    		$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
+    		$smartAcq = SMTBaseOtdrTraceFileUtil::isSmartAcqFileExtension($smartAcqTraceExtension) && (SMTTestMode::isTappingMode( $linkTestDetailDto->getTestMode()) || $isLoc );
     		
-    		SMTLogger::getInstance()->trace( sprintf("Retrieve last otdr monitoring acquisitiontrace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+    		SMTLogger::getInstance()->trace( sprintf("Retrieve last otdr monitoring acquisitiontrace file %s localisation : %d  smartAcq: %d",  $traceFilePath, $isLoc, $smartAcq), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
     		
-    		$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::LAST_TEST_ACQUISITION_TRACE );
+    		$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::LAST_TEST_ACQUISITION_TRACE, SMTTraceFileType::getFileType($traceFilePath), $smartAcq, $SOM, $EOM);
     		
     		$this->getContext()->getHttpResponse()->send( $page );
     	}
@@ -612,7 +761,8 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
                 	        	break;
             	        	case SMTOtdrTraceType::ACQ:
             	        	    $otdrTraceType = SMTOtdrTraceType::LAST_TEST_ACQUISITION_TRACE;
-            	        	    $traceFilePath = SMTOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId, $portid);
+            	        	    //for trace download we want always a SOR file
+            	        	    $traceFilePath = SMTOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId, $portid, $isLoc, FALSE);
             	        		break;
             	        	default:
             	        	    throw new SMTLinkTestException( SMTLinkTestException::ERROR_MISSING_OTDR_TRACE, "invalid trace type ".$traceType );
