@@ -55,7 +55,7 @@ class SMTAccessControl implements iAuthenticate
 	{
 	    $isAllowedToExecute = false;
 	    $userIdentifiers = null;
-	    
+	    $isApiRequest = self::isApiRequest();
 	    
 	    //SMTRestlerRouter injected by framework
 	    $context = SMTContext::getContext( $this->restler );
@@ -64,7 +64,7 @@ class SMTAccessControl implements iAuthenticate
 	    $session = $context->getSessionContext( self::isSessionTimeoutToCheck() );
 	    
 	    //try to login directly from http request header if the user is not already logged in
-	    if ( $session->getUser() == null )
+	    if ( ($session->getUser() == null) || ( $isApiRequest) ) //require login for each public API request
 	    {
 	        $userIdentifiers = $context->getHttpRequest()->decodeUserAuthorizationFromHeader();
 	        if ( $userIdentifiers != null )
@@ -72,7 +72,11 @@ class SMTAccessControl implements iAuthenticate
 	            //test if user exists
 	            $user = SMTUserUtil::authenticate($context, $userIdentifiers[0], "", base64_encode($userIdentifiers[1]) );	
 	            $session->setUser($user);	    
-	        }	        
+	        }
+	        else
+	        {
+	        	$session->setUser(NULL);
+	        }
 	    }    
 	    
 	    // test if one required role is a role of the current user 
@@ -80,7 +84,7 @@ class SMTAccessControl implements iAuthenticate
 	    if ( $session->getUser() != null ) 
 	    {
 	    	// check only Token against Cross-Site Request Forgery for web application, not for API (authorization from header) which doesn't use PHP session cookie
-	    	if ( ($userIdentifiers != null) || ( $context->getHttpRequest()->checkReferer() && $context->getHttpRequest()->checkToken( $this->restler->getTestRequestData() )) )
+	    	if ( $isApiRequest || ( $context->getHttpRequest()->checkReferer() && $context->getHttpRequest()->checkToken( $this->restler->getTestRequestData() )) )
 	    	{
 		        if ( is_array( $this->requires  ) )
 		        {
@@ -153,5 +157,16 @@ class SMTAccessControl implements iAuthenticate
 	{
 	    return !( strpos( $_SERVER["REQUEST_URI"], "/".SMTIService::MESSAGE_SERVICE."/consumer" ) !== FALSE );
 	}
+	
+	/**
+	 * Filter queries coming from PUBLIC API.
+	 *
+	 * @return boolean
+	 */
+	private static function isApiRequest()
+	{
+		return ( (strpos( $_SERVER["REQUEST_URI"], "/api/" ) !== FALSE) || (strpos( $_SERVER["REQUEST_URI"], "/acquisitions/files" ) !== FALSE));
+	}
+
 }
 ?>
\ No newline at end of file
