@@ -25,6 +25,8 @@ use app\services\SMTIService;
 use app\services\SMTService;
 
 use app\parser\SMTOtuApi;
+use app\admin\SMTOtuType;
+use app\admin\SMTOtuMode;
 
 /**
  * Service to setup the OTU features (ethernet, modules, switches, Email, SNMP) and display its configuration.
@@ -119,7 +121,7 @@ class SMTEthernetService extends SMTService implements SMTIService
     	{
     	    $ethernet = new SMTEthernet();
     	    $ethernet->setContext( $this->getContext() );
-    	    $ipv4 = $ethernet->getIpv4Config();   
+    	    $ipv4 = $ethernet->getIpv4Config();
     	}
     	catch ( \Exception $e )
     	{
@@ -142,7 +144,7 @@ class SMTEthernetService extends SMTService implements SMTIService
     	{
     	    $ethernet = new SMTEthernet();
     	    $ethernet->setContext( $this->getContext() );
-    	    $ipv6 = $ethernet->getIpv6Config();    
+    	    $ipv6 = $ethernet->getIpv6Config();
     	}
     	catch ( \Exception $e )
     	{
@@ -242,7 +244,18 @@ class SMTEthernetService extends SMTService implements SMTIService
     	    $ethernetConfig->setEnhancedSecurity($enhancedSecurity);
     	    $ethernetConfig->setHostName($hostName);
     	    $ethernetConfig->setIpv4($ipv4);
-    	    $ethernetConfig->setIpv6($ipv6);    	   
+    	    $ethernetConfig->setIpv6($ipv6);
+    	    if ( SMTOtuType::isOtu8KV2() && SMTOtuMode::isONMSi() )
+    	    {
+    	    	try
+    	    	{
+    	    		$ethernet->getBackupRoute($ethernetConfig);
+    	    	}
+    	    	catch(\Exception $e)
+    	    	{
+    	    		$this->getContext()->traceException($e);
+    	    	}
+    	    }
     	}
     	catch ( \Exception $e )
     	{
@@ -266,48 +279,63 @@ class SMTEthernetService extends SMTService implements SMTIService
         //if firewall config update fails, continue to set the ip config
     	try
     	{    	   
-    	    $ethernetConfig = SMTEthernetDto::getInstance( $request_data );    	    
-    	    
-    	    //Dans le cas d'une config de firewall custom
-    	    if ( strcasecmp( $ethernetConfig->getFirewallMode(), SMTFirewall::FIREWALL_CUSTOM) == 0 )
+    	    $ethernetConfig = SMTEthernetDto::getInstance( $request_data );
+    	    //pas de changement du firewall en mode ONMSi
+    	    if ( !SMTOtuMode::isONMSi() )
     	    {
-    	        $customFirewallConfig = $ethernetConfig->getCustomFirewall();
-    	        //if firewall config is set
-    	        if ( isset ($customFirewallConfig) && $customFirewallConfig != NULL )
-    	        {
-    	            $firewall = new SMTFirewall();
-    	            $firewall->setContext( $this->getContext() );
-    	            //si la config du firewall n'est pas vide
-    	            if ( count ($customFirewallConfig->getCustomFirewall() ) > 0 )
-    	            {
-    	                $firewall->saveConfig($customFirewallConfig->getCustomFirewall());
-    	                //if config save fails, don't change to custom firewall (only change when everything got right)
-    	                $this->setFirewallMode( SMTFirewall::FIREWALL_CUSTOM );
-    	            }
-    	            else
-    	            {
-    	                $this->getContext()->getLogger()->trace("customFirewallConfig empty", SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__ );
-    	            }
-    	        }
-    	        else
-    	        {
-    	            //check that custom firewall config file exists, before switching to custom firewall
-    	            $firewall = new SMTFirewall();
-    	            $firewall->setContext( $this->getContext() );
-    	            $firewall->readCustomFirewallConfig();
-    	            $this->setFirewallMode( SMTFirewall::FIREWALL_CUSTOM );
-    	        }
-    	    }
-    	    else
-    	    {
-    	        $this->setFirewallMode( $ethernetConfig->getFirewallMode() );
+    	    	//Dans le cas d'une config de firewall custom
+	    	    if ( strcasecmp( $ethernetConfig->getFirewallMode(), SMTFirewall::FIREWALL_CUSTOM) == 0 )
+	    	    {
+	    	        $customFirewallConfig = $ethernetConfig->getCustomFirewall();
+	    	        //if firewall config is set
+	    	        if ( isset ($customFirewallConfig) && $customFirewallConfig != NULL )
+	    	        {
+	    	            $firewall = new SMTFirewall();
+	    	            $firewall->setContext( $this->getContext() );
+	    	            //si la config du firewall n'est pas vide
+	    	            if ( count ($customFirewallConfig->getCustomFirewall() ) > 0 )
+	    	            {
+	    	                $firewall->saveConfig($customFirewallConfig->getCustomFirewall());
+	    	                //if config save fails, don't change to custom firewall (only change when everything got right)
+	    	                $this->setFirewallMode( SMTFirewall::FIREWALL_CUSTOM );
+	    	            }
+	    	            else
+	    	            {
+	    	                $this->getContext()->getLogger()->trace("customFirewallConfig empty", SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__ );
+	    	            }
+	    	        }
+	    	        else
+	    	        {
+	    	            //check that custom firewall config file exists, before switching to custom firewall
+	    	            $firewall = new SMTFirewall();
+	    	            $firewall->setContext( $this->getContext() );
+	    	            $firewall->readCustomFirewallConfig();
+	    	            $this->setFirewallMode( SMTFirewall::FIREWALL_CUSTOM );
+	    	        }
+	    	    }
+	    	    else
+	    	    {
+	    	        $this->setFirewallMode( $ethernetConfig->getFirewallMode() );
+	    	    }
     	    }
 	    }
 	    catch ( \Exception $e )
 	    {
 	        $this->getContext()->traceException($e);
 	    }
-	    
+	    //backup route uniquement en mode ONMSi et sur OTU8kv2
+	    if ( SMTOtuType::isOtu8KV2() && SMTOtuMode::isONMSi() )
+	    {
+	    	try
+	    	{
+	    		$ethernet->setBackupRoute($ethernetConfig->getBackupRouteActive());
+	    	}
+	    	catch(\Exception $e)
+	    	{
+	    		$this->getContext()->traceException($e);
+	    	}
+	    }
+
 	    try 
 	    {	    
     	    //Only change ip settings if they have changed
@@ -323,7 +351,7 @@ class SMTEthernetService extends SMTService implements SMTIService
     	        $this->getContext()->setOTUReboot();
     	    }
     	    else
-    	    {    	        
+    	    {
     	        try
     	        {
     	        	$enhancedSecurity = $this->getEnhancedSecurity();
@@ -343,6 +371,17 @@ class SMTEthernetService extends SMTService implements SMTIService
         	    $ethernetConfig->setEnhancedSecurity($enhancedSecurity);
         	    $ethernetConfig->setIpv4($ipv4);
         	    $ethernetConfig->setIpv6($ipv6);
+        	    if ( SMTOtuType::isOtu8KV2() && SMTOtuMode::isONMSi() )
+        	    {
+        	    	try
+        	    	{
+        	    		$ethernet->getBackupRoute($ethernetConfig);
+        	    	}
+        	    	catch(\Exception $e)
+        	    	{
+        	    		$this->getContext()->traceException($e);
+        	    	}
+        	    }
     	    }
     	}
     	catch ( \Exception $e )
