@@ -33,17 +33,17 @@ use app\serviceshelper\monitoring\SMTLinkTest;
 
 use app\serviceshelper\system\SMTOtu;
 
-use app\serviceshelper\media\SMTSms;
-use app\util\SMTLogger;
 use app\services\monitoring\SMTOtuMonitoringTestThresholdDto;
+use app\serviceshelper\media\SMTSms;
 use app\settings\SMTSmartOtuSettings;
+use app\util\SMTLogger;
 
-use app\view\SMTTestRestApiPage;
+use app\admin\SMTOtuMonitoringOptions;
+use app\parser\SMTOtuApi;
+use app\services\security\SMTAccessControl;
 use app\services\SMTIService;
 use app\services\SMTService;
-use app\services\security\SMTAccessControl;
-use app\parser\SMTOtuApi;
-use app\serviceshelper\module\SMTModule;
+use app\view\SMTTestRestApiPage;
 
 date_default_timezone_set('UTC');
 
@@ -68,7 +68,7 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         {
     		$status = new SMTOtuStatusDto();   
     		
-    		$smsOptionValid = $this->getContext()->getSettings()->isSmsOptionValid();
+    		$smsOptionValid = SMTSmartOtuSettings::isSmsOptionValid();
     		if ( $smsOptionValid == NULL )
     		{    		
     		    try 
@@ -78,7 +78,7 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         		    $smsOptionValid = $sms->isModemOption();
         		    $smsOptionValid = $smsOptionValid && $sms->isValidModemType();
         		    //save sms option availability in cache
-        		    $this->getContext()->getSettings()->setSmsOptionValid( $smsOptionValid );
+        		    SMTSmartOtuSettings::setSmsOptionValid( $smsOptionValid );
     		    }
     		    catch ( \Exception $e )
     		    {
@@ -88,7 +88,28 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
     		        $smsOptionValid = FALSE;
     		    }
     		}
-    		$status->setSmsOption( $smsOptionValid );    
+    		$status->setSmsOption( $smsOptionValid );
+    		
+    		$relayOptionValid = SMTSmartOtuSettings::isRelayOptionValid();
+    		if ( $relayOptionValid== NULL )
+    		{
+    			try
+    			{
+    				$otu = new SMTOtu();
+    				$otu->setContext( $this->getContext() );
+    				$relayOptionValid = $otu->isRelayOption();
+    				//save relay option availability in cache
+    				SMTSmartOtuSettings::setRelayOptionValid( $relayOptionValid);
+    			}
+    			catch ( \Exception $e )
+    			{
+    				//catch exception to retrieve settings and status even if an error occurs
+    				$this->getContext()->getLogger()->traceException( $e );
+    				//set by default sms option as not available in case of error (OTU application not available...)
+    				$smsOptionValid = FALSE;
+    			}
+    		}
+    		$status->setRelayOption( $relayOptionValid );
     		
             try 
 		    {
@@ -151,7 +172,7 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         	$linkTest->setContext( $this->getContext() );
         	
         	$setup->setSequensorOn( $linkTest->isSequensorOn() );
-        	$setup->setLogLevel( $this->getContext()->getSettings()->getLogLevel() );
+        	$setup->setLogLevel( SMTSmartOtuSettings::getLogLevel() );
         	
         	$otuRftyMode = $this->sendReceive( SMTOtuApi::getOtuRFTYMode() );
         	$setup->setOtuRftyMode( $otuRftyMode );
@@ -166,7 +187,7 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         	
         	if (SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2())
         	{
-            	if ( strcasecmp( trim( $this->sendReceive( SMTOtuApi::getModuleName( SMTModule::MOD3 ) )," \t\n\r\0\"" ), SMTOtuApi::RES_NONE ) != 0 )
+        		if ( strcasecmp( trim( $this->sendReceive( SMTOtuApi::getModuleName( SMTModuleDto::MOD3 ) )," \t\n\r\0\"" ), SMTOtuApi::RES_NONE ) != 0 )
             	{
             		$setup->setDTSSModule( TRUE );
             	}
@@ -183,10 +204,47 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         		$this->getContext()->getLogger()->traceException( $ex);
         	}
         	
+        	if ( SMTOtuType::isOtu8KV2() )
+        	{
+	        	try
+	        	{
+	        		$isBackup = $this->sendReceive(SMTOtuApi::CMD_is_Backup_Hard_Disk_Option);
+	        		$isBackup = str_replace("\"","",$isBackup);
+	        		$isBackupHardDiskOption = ( strcmp($isBackup, 'TRUE') == 0)? TRUE : FALSE;
+	        		$setup->setHddBackup($isBackupHardDiskOption);
+	        	}
+	        	//catch the exception
+	        	catch ( \Exception $e )
+	        	{
+	        		$this->getContext()->traceException($e);
+	        	}
+        	}
+        	
+        	try
+        	{
+        		//retrieve monitoring options
+        		$monitoringOptions = SMTOtuMonitoringOptions::getOtuMonitoringOptions($this->getContext() );
+        		$setup->setMonitoringOptions($monitoringOptions);
+        	}
+        	catch ( \Exception $e )
+        	{
+        		$this->handleException($e);
+        	}
+        	
+//         	try
+//         	{
+//         		//retrieve monitoring mode
+//         		$mode = trim( $this->sendReceive( SMTOtuApi::get_otu_mon_mode( ) ) );
+//         		$setup->setMonitoringMode($mode);
+//         	}
+//         	catch ( \Exception $e )
+//         	{
+//         		//don't throw exception here, either SmartOTU will not be initialized
+//         		SMTLogger::getInstance()->traceException($e);
+//         	}
+        	
         	$setup->setSoftwareOption(SMTLicence::retrieveSoftwareOptions($this->getContext()));
         	
-        	
-        	
         }
         catch ( \Exception $e )
         {
@@ -532,6 +590,27 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
     
     	return $thresholds->getJsonData();
     }    
+
+    /**
+     *
+     * @url GET /tappingthresholds
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function fetchDefaultTappingThresholds()
+    {
+    	try
+    	{
+    		$thresholds = SMTSmartOtuSettings::getDefaultTappingThresholds();
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    	
+    	return $thresholds->getJsonData();
+    }
     
     /**
      *
