@@ -32,6 +32,9 @@ use app\parser\SMTOtuApi;
 use app\sharedmemory\SMTMemoryManager;
 use app\settings\SMTOtuStatusCacheDto;
 use app\admin\SMTOtuMode;
+use app\serviceshelper\otau\SMTRotauManager;
+use app\admin\SMTOtuType;
+use app\util\SMTInvalidValueException;
 
 /**
  * Service to setup the OTU internal switch features and display its configuration.
@@ -45,6 +48,12 @@ class SMTSwitchService extends SMTService implements SMTIService
      * @var \app\serviceshelper\otau\SMTSwitchManager
      */
     private $switchManager = NULL;
+    
+    /**
+     *
+     * @var \app\serviceshelper\otau\SMTRotauManager
+     */
+    private $rotauManager = NULL;
         
     /**
      * Full json request data are by default stored in an array in parameter Default::$fullRequestDataName='request_Data'
@@ -57,7 +66,15 @@ class SMTSwitchService extends SMTService implements SMTIService
     function updateSwitch( $request_data )
     {       
     	try
-    	{    	    
+    	{
+    		if ( $this->switchManager == NULL )
+    		{
+    			$this->switchManager = new SMTSwitchManager();
+    			$this->switchManager->setContext( $this->getContext() );
+    		}
+    		//no OSX setup
+    		$this->switchManager->disableSequencer(FALSE);
+    		
     	    $configDetectSwitchDto = SMTConfDetSwitchDto::getInstance( $request_data );
     	    
     	    //if a difference exists,
@@ -83,7 +100,10 @@ class SMTSwitchService extends SMTService implements SMTIService
     {        
         $configDetectSwitchDto = new SMTConfDetSwitchDto();    
     	try
-    	{    	        	    
+    	{
+    		//no OSX setup
+    		$this->getSwitchManager(TRUE)->disableSequencer(FALSE);
+    		
     	    $configDetectSwitchDto->setConfigured( $this->getSwitchManager(TRUE)->getConfiguredSwitchDto() );
     	    $configDetectSwitchDto->setDetected( $this->getSwitchManager(TRUE)->getDetectedSwitchDto() );
     	    $configDetectSwitchDto->setSwitchDifference( $this->getSwitchManager(TRUE)->isDifference() );
@@ -117,6 +137,9 @@ class SMTSwitchService extends SMTService implements SMTIService
     			$this->switchManager->setContext( $this->getContext() );
     		}
     		
+    		//no OSX setup
+    		$this->switchManager->disableSequencer(FALSE);
+    		
     		// si l'on n'est pas en mode SmartOTU, on force la detection si elle n'a jamais ete faite
     		if ( !SMTOtuMode::isSmartOtu() && !SMTOtuStatusCacheDto::getSwitchDetectedOnce() )
     		{
@@ -204,8 +227,11 @@ class SMTSwitchService extends SMTService implements SMTIService
     		{
     			$this->switchManager = new SMTSwitchManager();
     			$this->switchManager->setContext( $this->getContext() );
-    			$this->switchManager->setOsxAddress($osxAddress);
     		}
+    		//OSX setup in progress
+    		$this->switchManager->disableSequencer(TRUE);
+    		
+    		$this->switchManager->setOsxAddress($osxAddress);
     		
 	        //sleep 2s before requesting the config
 			sleep(2);
@@ -230,6 +256,14 @@ class SMTSwitchService extends SMTService implements SMTIService
     	
     	try
     	{
+    		if ( $this->switchManager == NULL )
+    		{
+    			$this->switchManager = new SMTSwitchManager();
+    			$this->switchManager->setContext( $this->getContext() );
+    		}
+    		//start OSX setup
+    		$this->switchManager->disableSequencer(TRUE);
+    		
     		$osxListArray = SMTMemoryManager::fetchAll( SMTOsxListDto::getClass() );
     		if ( $osxListArray != NULL && is_array( $osxListArray) && count($osxListArray) > 0 )
     		{
@@ -239,12 +273,6 @@ class SMTSwitchService extends SMTService implements SMTIService
     			}
     		}
     		
-    		if ( $this->switchManager == NULL )
-    		{
-    			$this->switchManager = new SMTSwitchManager();
-    			$this->switchManager->setContext( $this->getContext() );
-    		}
-    		
     		//update big topology status
     		$osxList->setIsBigTopology($this->switchManager->isBigTopology());
     		$osxList->setIsOsxPowerOn($this->switchManager->getOsxPowerOn());
@@ -270,9 +298,12 @@ class SMTSwitchService extends SMTService implements SMTIService
     		if ( $this->switchManager == NULL )
     		{
     			$this->switchManager = new SMTSwitchManager();
-    			$this->switchManager->setContext( $this->getContext() );    			    			
+    			$this->switchManager->setContext( $this->getContext() );
     		}
     		
+    		//OSX setup in progress
+    		$this->switchManager->disableSequencer(TRUE);
+    		
     		$osxList= $this->switchManager->fullScan();
     		
     		//update big topology status
@@ -303,6 +334,9 @@ class SMTSwitchService extends SMTService implements SMTIService
     			$this->switchManager->setContext( $this->getContext() );
     		}
     		
+    		//OSX setup in progress
+    		$this->switchManager->disableSequencer(TRUE);
+    		
     		$this->switchManager->showOsx($osxAddress);
     	}
     	catch ( \Exception $e )
@@ -324,6 +358,15 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
+    		if ( $this->switchManager == NULL )
+    		{
+    			$this->switchManager = new SMTSwitchManager();
+    			$this->switchManager->setContext( $this->getContext() );
+    		}
+    		
+    		//OSX setup in progress
+    		$this->switchManager->disableSequencer(TRUE);
+    		
     		SMTSwitchManager::setBigTopology($bigTopology == 1? 'TRUE': 'FALSE', $this->getContext()->getOtuSocket() );
     	}
     	catch ( \Exception $e )
@@ -349,9 +392,13 @@ class SMTSwitchService extends SMTService implements SMTIService
     		{
     			$this->switchManager = new SMTSwitchManager();
     			$this->switchManager->setContext( $this->getContext() );
-    			$this->switchManager->setOsxPower($osxPower);
     		}
     		
+    		//OSX setup in progress
+    		$this->switchManager->disableSequencer(TRUE);
+    		
+    		$this->switchManager->setOsxPower($osxPower);
+    		
     		//sleep 10s before requesting the config if the OSX port was switched on
     		if ( strcasecmp($osxPower, SMTSwitchManager::OSX_POWER_ON) == 0 )
     		{
@@ -382,6 +429,157 @@ class SMTSwitchService extends SMTService implements SMTIService
         return $this->switchManager;
     }
     
+    /**
+     *
+     * @url GET /rotau/
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function fetchRotauConfig()
+    {
+    	$configDetectRotauDto= new SMTConfDetRotauDto();
+    	try
+    	{
+	    	if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && SMTOtuType::isOtu8KV2())
+	    	{
+	    		if ( $this->rotauManager== NULL )
+	    		{
+	    			$this->rotauManager= new SMTRotauManager();
+	    			$this->rotauManager->setContext( $this->getContext() );
+	    		}
+	    		
+	    		$this->rotauManager->retrieve($configDetectRotauDto);	    		
+	    	}
+	    	else
+	    	{
+	    		new SMTInvalidValueException(SMTInvalidValueException::INVALID_VALUE, NULL, "ROTAU", "not supported");
+	    	}
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    	return $configDetectRotauDto->getJsonData();
+    }    
+    
+    /**
+     *
+     * @url POST /rotau/{rotauAddress}
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function addRotau($rotauAddress)
+    {
+    	try
+    	{
+    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && SMTOtuType::isOtu8KV2())
+    		{
+	    		if ( $this->rotauManager== NULL )
+	    		{
+	    			$this->rotauManager= new SMTRotauManager();
+	    			$this->rotauManager->setContext( $this->getContext() );
+	    		}
+	    		$this->rotauManager->add($rotauAddress);
+    		}
+    		else
+    		{
+    			new SMTInvalidValueException(SMTInvalidValueException::INVALID_VALUE, NULL, "ROTAU", "not supported");
+    		}
+    		
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    	return $this->fetchRotauConfig();
+    }
+    
+    /**
+     *
+     * @url DELETE /rotau/{$rotauId}
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function removeRotau($rotauId)
+    {
+    	try
+    	{
+    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && SMTOtuType::isOtu8KV2())
+    		{
+	    		if ( $this->rotauManager== NULL )
+	    		{
+	    			$this->rotauManager= new SMTRotauManager();
+	    			$this->rotauManager->setContext( $this->getContext() );
+	    		}
+	    		$this->rotauManager->remove($rotauId);
+    		}
+    		else
+    		{
+    			new SMTInvalidValueException(SMTInvalidValueException::INVALID_VALUE, NULL, "ROTAU", "not supported");
+    		}
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    	return $this->fetchRotauConfig();
+    }
+    
+    /**
+     *
+     * @url POST /rotau/
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires install}
+     */
+    function update($request_data)
+    {
+    	try
+    	{
+    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && SMTOtuType::isOtu8KV2())
+    		{
+    			$configDetectRotauDto = SMTConfDetRotauDto::getInstance( $request_data );
+    			if ( $configDetectRotauDto!= null)
+		    	{  
+		    		$this->rotauManager= new SMTRotauManager();
+		    		$this->rotauManager->setContext( $this->getContext() );
+// 		    		$this->rotauManager->retrieve($configDetectRotauDto);
+		    	}
+		    	$index = 0;
+		    	$differences = $configDetectRotauDto->getSwitchDifferences();
+		    	foreach($differences as $difference)
+		    	{
+		    		if ($difference)
+		    		{
+		    			// WARNING TRAC 907: UPDATE ROTAU in OTU configuration when its detection is different from from saved configuration..
+		    			// If the detection is empty, we use the method remove_rotau_ip which removes the rotau from the configuration
+		    			// and removes its ip declaration in OTU
+		    			if ( $configDetectRotauDto->isRotauDetected($index) )		
+		    			{
+		    				$this->rotauManager->update($configDetectRotauDto->getRotauDetected($index));
+		    			}
+		    			else
+		    			{
+		    				$this->rotauManager->remove($index);
+		    			}
+		    		}
+		    		$index++;
+		    	}
+    		}
+    		else
+    		{
+    			new SMTInvalidValueException(SMTInvalidValueException::INVALID_VALUE, NULL, "ROTAU", "not supported");
+    		}
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    }
+    
     /**
      * @url GET /test/updateswitch
      */
