@@ -178,7 +178,7 @@ class SMTAlarmFactory
 			    }			    
 
 			    //update alarm specific problem
-			    $alarm->setSpecificProblemCode( $otuAlarm->getAttenuation()->getSpecificProblemCode() );			    			    
+			    $alarm->setSpecificProblemCode( $otuAlarm->getAttenuation()->getSpecificProblemCode() );
 			    $alarm->updateSpecificProblemText();
 			}
 			else if ( ($otuAlarm->getAttenuation() != NULL) && ($otuAlarm->getAttenuation()->getSpecificProblemCode() == SMTAlarmSpecificProblemCode::OTU_OPT_ALARM_BACK_TO_NORMAL_STATE_CODE) )
@@ -420,10 +420,16 @@ class SMTAlarmFactory
 			$alarm->setClearStatus( FALSE );
 			$alarm->setDiscriminator( $alarmDiscriminator );
 			$alarm->setSpecificProblemId( $otuAlarm->getSpecificProblemId() );
-			$alarm->setOtuAdditionalInfoId( $otuAlarm->getAdditionalInfo() );
+			
+			//since EPT #6693 alarm info identifier is given by the text field (OTU alarm additional info content is kept for compatibility)
+			$alarm->setOtuAdditionalInfoId( $otuAlarm->getText() );
+			$alarm->setOtuAdditionalInfo( $otuAlarm->getAdditionalInfo() );
+			
+			//$alarm->setOtuAdditionalInfoId( $otuAlarm->getAdditionalInfo() );
+			
 			$alarm->setAlarmType( $otuAlarm->getEventTypeCode() );
 			$alarm->setAdditionText( self::buildSystemAlarmAdditionalInfo( $otuAlarm ) );
-			$alarm->setSpecificProblemCode( $otuAlarm->getSpecificProblemCode() );			
+			$alarm->setSpecificProblemCode( $otuAlarm->getSpecificProblemCode() );
 		}
 
 		// if system alarm DTO can be created or exists
@@ -561,93 +567,46 @@ class SMTAlarmFactory
      */
     private static function buildSystemAlarmAdditionalInfo( SMTOtuSystemAlarmDto $otuAlarm  )
     {
-    	$additionalInfo = $otuAlarm->getAdditionalInfo();
+    	$additionalInfo = $otuAlarm->getText();
     
     	// on indique un eventuel sous composant correlant :
     	switch ( $otuAlarm->getSpecificProblemCode() )
     	{
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MISSING_OR_CORRUPTED_FILE_CODE:
-    			//$additionalInfo = "file=".$otuAlarm->getAdditionalInfo();
-    			$additionalInfo = $otuAlarm->getAdditionalInfo();//"otu";
+    			$additionalInfo = $otuAlarm->getText();
     			break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_LOCAL_MODE_CODE:
-    			$additionalInfo = $otuAlarm->getAdditionalInfo();//"otu";
+    			$additionalInfo = $otuAlarm->getText();
     			break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_INNER_APPLICATION_COMMUNICATION_PROBLEM_CODE:
-    			$additionalInfo = $otuAlarm->getAdditionalInfo();//"otu";
+    			$additionalInfo = $otuAlarm->getText();
     			break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_REBOOT_CODE:
     			
-    			$additionalInfo = $otuAlarm->getAdditionalInfo();
+    			$additionalInfo = $otuAlarm->getText();
     			break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HARDDISK_SPACE_CODE:
-    			$additionalInfo =$otuAlarm->getAdditionalInfo();//"otu";
+    			$additionalInfo =$otuAlarm->getText();
     			break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_TEMPERATURE_CODE:
-    			if ( SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_MODULE_1 == $otuAlarm->getAdditionalInfo() || SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_MODULE_2 == $otuAlarm->getAdditionalInfo())
-    			{
-    				$additionalInfo ="module=".$otuAlarm->getAdditionalInfo();
-    			}
-    			else if ( SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_CPU == $otuAlarm->getAdditionalInfo() )
-    			{
-    				$additionalInfo ="cpu ".$otuAlarm->getAdditionalInfo();
-    			}
+    			$additionalInfo =$otuAlarm->getText();
     			break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SWITCH_PROBLEM_CODE:
-    			$parts = explode(',', $otuAlarm->getAdditionalInfo() );
-    			if (isset($parts[0]))
-    			{
-    				$temp1 = $parts[0];
-    				if (isset($parts[1]))
-    				{
-    					$temp0 = $parts[1];
-    				}
-    			}
-    
-    			$parts = explode(" ",$temp0);
-    			if (isset($parts[0]))
-    			{
-    				$temp2 = $parts[0];
-    				if (isset($parts[1]))
-    				{
-    					$temp3 = $parts[1];
-    				}
-    			}
-    			 
-    			if ( strcmp($temp2, SMTMacroSwitch::INTERNAL) == 0 )
-    			{
-    				$additionalInfo = sprintf( "switch=%s", $temp1 );
-    			}
-    			else if ( strcmp($temp2, SMTMacroSwitch::OSU) == 0 )
-    			{
-    				$additionalInfo = sprintf( "osx=%s", $temp1 );
-    			}
-    			else if ( strcmp($temp2, SMTMacroSwitch::ROTAU) == 0 )
-    			{
-    				$additionalInfo = sprintf( "rotau=%s", $temp1 );
-    			}
+    			$additionalInfo = $otuAlarm->getText();
     			break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MODULE_PROBLEM_CODE:
     			//MOD = 0 or 1 => +1
-    			$additionalInfo ="module=".($otuAlarm->getAdditionalInfo());
+    			$additionalInfo ="module=".($otuAlarm->getText());
     			break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MODULE_COMPATIBILITY_CODE:
     			//MOD = 0 or 1 => +1
-    			$additionalInfo ="module=".($otuAlarm->getAdditionalInfo());
+    			$additionalInfo ="module=".($otuAlarm->getText());
     			break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SWITCH_COMPATIBILITY_CODE:
-    			if ( strcmp ( $otuAlarm->getAdditionalInfo(), "0") == 0 )
-    			{
-    		        $additionalInfo ="switch=".($otuAlarm->getAdditionalInfo());
-    			}
-    			else
-    			{
-    			    $additionalInfo ="rotau=".($otuAlarm->getAdditionalInfo());
-    			}
-    			
+    			$additionalInfo = $otuAlarm->getText();
     		    break;
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_LINKS_BACK_TO_AVAILABLE_CODE:
-    			$additionalInfo =$otuAlarm->getAdditionalInfo();
+    			$additionalInfo =$otuAlarm->getText();
     			break;
     			//
     		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MISSING_REFERENCE_TRACE_CODE:
@@ -663,7 +622,7 @@ class SMTAlarmFactory
     			$additionalInfo = sprintf("test=%s", $temp1 );
     			break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SUCCESSFUL_CALLBACK_CODE:
-    			$additionalInfo ="media=".($otuAlarm->getAdditionalInfo());
+				$additionalInfo ="media=".($otuAlarm->getText());
     			break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_TEST_DRIFT_CODE:
 				$parts = explode(',', $otuAlarm->getAdditionalInfo() );
@@ -678,101 +637,103 @@ class SMTAlarmFactory
             	$additionalInfo = sprintf("test=%s", $temp1 );
             	break;
         	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_COMMUNICATION_TEST_CODE:
-        	    $additionalInfo ="media=".($otuAlarm->getAdditionalInfo());//."/interface=ETH0";
+        		$additionalInfo ="media=".($otuAlarm->getText());//."/interface=ETH0";
         	    break;
         	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HEARTBEAT_CODE:
-        		$additionalInfo = $otuAlarm->getAdditionalInfo();//"otu";
+        		$additionalInfo = $otuAlarm->getText();//"otu";
     			break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HARDWARE_PROBLEM_CODE:
-    			$additionalInfo =$otuAlarm->getAdditionalInfo();
+				$additionalInfo =$otuAlarm->getText();
     			break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SOFTWARE_PROBLEM_CODE:
     			//$additionalInfo ="component=".($otuAlarm->getAdditionalInfo());
-				$additionalInfo = $otuAlarm->getAdditionalInfo();//"otu";
+				$additionalInfo = $otuAlarm->getText();//"otu";
     			break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MEASUREMENT_CYCLE_CODE:
-				$additionalInfo = $otuAlarm->getAdditionalInfo();
+				$additionalInfo = $otuAlarm->getText();
     			break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_ALARM_OVERFLOW_CODE:
-				$additionalInfo = $otuAlarm->getAdditionalInfo();
+				$additionalInfo = $otuAlarm->getText();
     			break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_GENERIC_ALARM_CODE:
-				$additionalInfo = $otuAlarm->getAdditionalInfo();//
+				$additionalInfo = $otuAlarm->getText();//
     			break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_REBUILD_CLEAR_CODE:
-				$additionalInfo = $otuAlarm->getAdditionalInfo();
+				$additionalInfo = $otuAlarm->getText();
     			break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HDD_FAILED_CODE:
-				$additionalInfo = $otuAlarm->getAdditionalInfo();
+				$additionalInfo = $otuAlarm->getText();
 				break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HDD_FAILED_USE_BACKUP_CODE:
-				$additionalInfo = $otuAlarm->getAdditionalInfo();
+				$additionalInfo = $otuAlarm->getText();
 				break;
 			case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_POWER_FAILURE_CODE:
-				$additionalInfo = $otuAlarm->getAdditionalInfo();
+				$additionalInfo = $otuAlarm->getText();
+				break;
+			case SMTAlarmSpecificProblemCode::OTU_SYST_REFERENCE_DRIFT_FAILURE_CODE:
+				$additionalInfo = $otuAlarm->getText().", ".MSG_LINK."=".$otuAlarm->getComment();
 				break;
     		default:
     		    break;
     	}
     	
     	return $additionalInfo;
-    	}
-    
-    
+    }
+    	
     /**
      * Build System Alarm Discriminator
-     * 
+     *
      * @param SMTOtuSystemAlarmDto $otuAlarm
      */
     public static function buildSystemAlarmDiscriminator( SMTOtuSystemAlarmDto $otuAlarm  )
     {
-        $alarmDiscriminator = "";        
-        
-        // on indique un eventuel sous composant correlant :
-        switch ( $otuAlarm->getSpecificProblemCode() )
-        {
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MISSING_OR_CORRUPTED_FILE_CODE:
-        	    $alarmDiscriminator ="file=".$otuAlarm->getAdditionalInfo().SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-                break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_LOCAL_MODE_CODE:
-                break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_INNER_APPLICATION_COMMUNICATION_PROBLEM_CODE:
-                break;
-            case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_REBOOT_CODE:
-                break;
-            case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HARDDISK_SPACE_CODE:
-                break;
-            case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_TEMPERATURE_CODE:
-        	    if ( SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_MODULE_1 == $otuAlarm->getAdditionalInfo() || SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_MODULE_2 == $otuAlarm->getAdditionalInfo())
-        	    {
-        	        $alarmDiscriminator ="module".$otuAlarm->getAdditionalInfo().SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    }
-        	    else if ( SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_CPU == $otuAlarm->getAdditionalInfo() )
-        	    {
-        	        $alarmDiscriminator ="cpu".SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    }
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SWITCH_PROBLEM_CODE:        	    
-        	    $parts = explode(',', $otuAlarm->getAdditionalInfo() );
-        	    if (isset($parts[0])) 
-        	    {
-        	    	$temp1 = $parts[0];
-        	    	if (isset($parts[1])) 
-        	    	{
-        	    		$temp0 = $parts[1];
-        	    	}
-        	    }
-
-        	    $parts = explode(" ",$temp0);
-        	    if (isset($parts[0]))
-        	    {
-        	    	$temp2 = $parts[0];
-        	    	if (isset($parts[1]))
-        	    	{
-        	    		$temp3 = $parts[1];
-        	    	}
-        	    }        	    
-        	    
+    	$alarmDiscriminator = "";
+    	
+    	// on indique un eventuel sous composant correlant :
+    	switch ( $otuAlarm->getSpecificProblemCode() )
+    	{
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MISSING_OR_CORRUPTED_FILE_CODE:
+    			$alarmDiscriminator ="file=".$otuAlarm->getAdditionalInfo().SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_LOCAL_MODE_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_INNER_APPLICATION_COMMUNICATION_PROBLEM_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_REBOOT_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HARDDISK_SPACE_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_TEMPERATURE_CODE:
+    			if ( SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_MODULE_1 == $otuAlarm->getAdditionalInfo() || SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_MODULE_2 == $otuAlarm->getAdditionalInfo())
+    			{
+    				$alarmDiscriminator ="module".$otuAlarm->getAdditionalInfo().SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			}
+    			else if ( SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_CPU == $otuAlarm->getAdditionalInfo() )
+    			{
+    				$alarmDiscriminator ="cpu".SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			}
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SWITCH_PROBLEM_CODE:
+    			$parts = explode(',', $otuAlarm->getAdditionalInfo() );
+    			if (isset($parts[0]))
+    			{
+    				$temp1 = $parts[0];
+    				if (isset($parts[1]))
+    				{
+    					$temp0 = $parts[1];
+    				}
+    			}
+    			
+    			$parts = explode(" ",$temp0);
+    			if (isset($parts[0]))
+    			{
+    				$temp2 = $parts[0];
+    				if (isset($parts[1]))
+    				{
+    					$temp3 = $parts[1];
+    				}
+    			}
+    			
     			if ( strcmp($temp2, SMTMacroSwitch::INTERNAL) == 0 )
     			{
     				$alarmDiscriminator = sprintf( "switch=0/osu=%s/otau=%s", $temp1, $temp3 ).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
@@ -786,81 +747,288 @@ class SMTAlarmFactory
     				$alarmDiscriminator = sprintf( "switch=%s", $temp1 ).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
     			}
     			break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MODULE_PROBLEM_CODE:
-        	    //MOD = 0 or 1 => +1
-        	    $alarmDiscriminator ="module=".($otuAlarm->getAdditionalInfo()+1).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MODULE_COMPATIBILITY_CODE:
-        	    //MOD = 0 or 1 => +1
-        	    $alarmDiscriminator ="module=".($otuAlarm->getAdditionalInfo()+1).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SWITCH_COMPATIBILITY_CODE:
-        	    $alarmDiscriminator ="switch=".($otuAlarm->getAdditionalInfo()).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    break;        	    
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_LINKS_BACK_TO_AVAILABLE_CODE:
-        	    //MOD = 0 or 1 => +1
-        	    $alarmDiscriminator ="module=".$otuAlarm->getAdditionalInfo().SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    break;
-        	//
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MISSING_REFERENCE_TRACE_CODE:
-        	    $parts = explode(',', $otuAlarm->getAdditionalInfo() );
-        	    if (isset($parts[0]))
-        	    {
-        	    	$temp1 = $parts[0];
-        	    	if (isset($parts[1]))
-        	    	{
-        	    		$temp2 = $parts[1];
-        	    	}
-        	    }        	     
-       	    	$alarmDiscriminator = sprintf("mode=%s/test=%s", $temp2, $temp1 ).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    break;        	    
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SUCCESSFUL_CALLBACK_CODE:
-        	    $alarmDiscriminator ="media=".($otuAlarm->getAdditionalInfo()).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    break;        	    
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_TEST_DRIFT_CODE:
-        	    $parts = explode(',', $otuAlarm->getAdditionalInfo() );
-        	    if (isset($parts[0]))
-        	    {
-        	    	$temp1 = str_replace('"', "", $parts[0] );
-        	    	if (isset($parts[1]))
-        	    	{
-        	    		$temp2 = $parts[1];
-        	    	}
-        	    }
-        	    $alarmDiscriminator = sprintf("mode=%s/test=%s", $temp2, $temp1 ).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-                break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_COMMUNICATION_TEST_CODE:
-        	    $alarmDiscriminator ="media=".($otuAlarm->getAdditionalInfo())."/interface=ETH0".SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HEARTBEAT_CODE:
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HARDWARE_PROBLEM_CODE:
-        	    $alarmDiscriminator ="component=".($otuAlarm->getAdditionalInfo()).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SOFTWARE_PROBLEM_CODE:
-        	    $alarmDiscriminator ="component=".($otuAlarm->getAdditionalInfo()).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MEASUREMENT_CYCLE_CODE:
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_ALARM_OVERFLOW_CODE:
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_GENERIC_ALARM_CODE:
-        	    break;
-        	case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_REBUILD_CLEAR_CODE:
-        	    break;
-    	    case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HDD_FAILED_CODE:
-    	    	break;
-    	    case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HDD_FAILED_USE_BACKUP_CODE:
-    	    	break;
-    	    case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_POWER_FAILURE_CODE:
-    	    	break;
-        	default:
-                SMTLogger::getInstance()->trace( sprintf("Unknown OTU specific problem code : %s", $otuAlarm->getSpecificProblemCode()), SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
-        		break;
-
-        }
-        return $alarmDiscriminator.$otuAlarm->getSpecificProblemCode();
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MODULE_PROBLEM_CODE:
+    			//MOD = 0 or 1 => +1
+    			$alarmDiscriminator ="module=".($otuAlarm->getAdditionalInfo()+1).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MODULE_COMPATIBILITY_CODE:
+    			//MOD = 0 or 1 => +1
+    			$alarmDiscriminator ="module=".($otuAlarm->getAdditionalInfo()+1).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SWITCH_COMPATIBILITY_CODE:
+    			$alarmDiscriminator ="switch=".($otuAlarm->getAdditionalInfo()).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_LINKS_BACK_TO_AVAILABLE_CODE:
+    		//MOD = 0 or 1 => +1
+    			$alarmDiscriminator ="module=".$otuAlarm->getAdditionalInfo().SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    			//
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MISSING_REFERENCE_TRACE_CODE:
+    			$parts = explode(',', $otuAlarm->getAdditionalInfo() );
+    			if (isset($parts[0]))
+    			{
+    				$temp1 = $parts[0];
+    				if (isset($parts[1]))
+    				{
+    					$temp2 = $parts[1];
+    				}
+    			}
+    			$alarmDiscriminator = sprintf("mode=%s/test=%s", $temp2, $temp1 ).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SUCCESSFUL_CALLBACK_CODE:
+    			$alarmDiscriminator ="media=".($otuAlarm->getAdditionalInfo()).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_TEST_DRIFT_CODE:
+    			$parts = explode(',', $otuAlarm->getAdditionalInfo() );
+    			if (isset($parts[0]))
+    			{
+    				$temp1 = str_replace('"', "", $parts[0] );
+    				if (isset($parts[1]))
+    				{
+    					$temp2 = $parts[1];
+    				}
+    			}
+    			$alarmDiscriminator = sprintf("mode=%s/test=%s", $temp2, $temp1 ).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_COMMUNICATION_TEST_CODE:
+    			$alarmDiscriminator ="media=".($otuAlarm->getAdditionalInfo())."/interface=ETH0".SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HEARTBEAT_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HARDWARE_PROBLEM_CODE:
+    			$alarmDiscriminator ="component=".($otuAlarm->getAdditionalInfo()).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SOFTWARE_PROBLEM_CODE:
+    			$alarmDiscriminator ="component=".($otuAlarm->getAdditionalInfo()).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MEASUREMENT_CYCLE_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_ALARM_OVERFLOW_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_GENERIC_ALARM_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_REBUILD_CLEAR_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HDD_FAILED_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HDD_FAILED_USE_BACKUP_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_POWER_FAILURE_CODE:
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_REFERENCE_DRIFT_FAILURE_CODE:
+    			$parts = explode(',', $otuAlarm->getAdditionalInfo());
+    			if (is_array($parts) )
+    			{
+    				$alarmDiscriminator = $parts[0].SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			}
+    			else
+    			{
+    				$alarmDiscriminator = ($otuAlarm->getAdditionalInfo()).SMTAlarmSpecificProblemDiscriminatorCode::ALARM_DISCRIMINATOR_SEPARATOR;
+    			}
+    			break;
+    		default:
+    			SMTLogger::getInstance()->trace( sprintf("Unknown OTU specific problem code : %s", $otuAlarm->getSpecificProblemCode()), SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
+    			break;
+    			
+    	}
+    	return $alarmDiscriminator.$otuAlarm->getSpecificProblemCode();
     }
 
+    /**
+     * Build System alarm additional Information for web services (don't use new text description for compatibility EPT #6693) from OTU alarm additional info
+     *
+     * @param string $specificProblemCode alarm specific problem OTU Code
+     * @param String $otuAdditionalInfo OTU alarm additional info
+     *
+     * @return string system alarm additional info built from combination of specific problem and additional info.
+     */
+    public static function buildSystemAlarmAdditionalInfoForWebService( $specificProblemCode, $otuAdditionalInfo)
+    {
+    	$additionalInfo = $otuAdditionalInfo;
+    	
+    	// on indique un eventuel sous composant correlant :
+    	switch ( $specificProblemCode)
+    	{
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MISSING_OR_CORRUPTED_FILE_CODE:
+    			//$additionalInfo = "file=".$otuAlarm->getAdditionalInfo();
+    			$additionalInfo = $otuAdditionalInfo;//"otu";
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_LOCAL_MODE_CODE:
+    			$additionalInfo = $otuAdditionalInfo;//"otu";
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_INNER_APPLICATION_COMMUNICATION_PROBLEM_CODE:
+    			$additionalInfo = $otuAdditionalInfo;//"otu";
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_REBOOT_CODE:
+    			
+    			$additionalInfo = $otuAdditionalInfo;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HARDDISK_SPACE_CODE:
+    			$additionalInfo =$otuAdditionalInfo;//"otu";
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_TEMPERATURE_CODE:
+    			if ( SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_MODULE_1 == $otuAdditionalInfo || SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_MODULE_2 == $otuAdditionalInfo)
+    			{
+    				$additionalInfo ="module=".$otuAdditionalInfo;
+    			}
+    			else if ( SMTSystemAlarmAdditionalInfoCode::INFO_ALARM_CPU == $otuAdditionalInfo )
+    			{
+    				$additionalInfo ="cpu ".$otuAdditionalInfo;
+    			}
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SWITCH_PROBLEM_CODE:
+    			$parts = explode(',', $otuAdditionalInfo );
+    			if (isset($parts[0]))
+    			{
+    				$temp1 = $parts[0];
+    				if (isset($parts[1]))
+    				{
+    					$temp0 = $parts[1];
+    				}
+    			}
+    			
+    			$parts = explode(" ",$temp0);
+    			if (isset($parts[0]))
+    			{
+    				$temp2 = $parts[0];
+    				if (isset($parts[1]))
+    				{
+    					$temp3 = $parts[1];
+    				}
+    			}
+    			
+    			if ( strcmp($temp2, SMTMacroSwitch::INTERNAL) == 0 )
+    			{
+    				$additionalInfo = sprintf( "switch=%s", $temp1 );
+    			}
+    			else if ( strcmp($temp2, SMTMacroSwitch::OSU) == 0 )
+    			{
+    				$additionalInfo = sprintf( "osx=%s", $temp1 );
+    			}
+    			else if ( strcmp($temp2, SMTMacroSwitch::ROTAU) == 0 )
+    			{
+    				$additionalInfo = sprintf( "rotau=%s", $temp1 );
+    			}
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MODULE_PROBLEM_CODE:
+    			//MOD = 0 or 1 => +1
+    			$additionalInfo ="module=".($otuAdditionalInfo);
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MODULE_COMPATIBILITY_CODE:
+    			//MOD = 0 or 1 => +1
+    			$additionalInfo ="module=".($otuAdditionalInfo);
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SWITCH_COMPATIBILITY_CODE:
+    			$parts = explode(',', $otuAdditionalInfo );
+    			if (isset($parts[0]))
+    			{
+    				$temp1 = $parts[0];
+    				if (isset($parts[1]))
+    				{
+    					$temp0 = $parts[1];
+    				}
+    			}
+    			
+    			$parts = explode(" ",$temp0);
+    			if (isset($parts[0]))
+    			{
+    				$temp2 = $parts[0];
+    				if (isset($parts[1]))
+    				{
+    					$temp3 = $parts[1];
+    				}
+    			}
+    			if( strcmp( $otuAdditionalInfo, "0" ) == 0 )    // EPT #6693 : faire retomber une alarme ancien format
+    			{
+    				$additionalInfo = "switch=0";
+    			}
+    			else if ( strcmp($temp2, SMTMacroSwitch::INTERNAL) == 0 )
+    			{
+    				$additionalInfo = sprintf( "switch=%s", $temp1 );
+    			}
+    			else if ( strcmp($temp2, SMTMacroSwitch::OSU) == 0 )
+    			{
+    				$additionalInfo = sprintf( "osx=%s", $temp1 );
+    			}
+    			else if ( strcmp($temp2, SMTMacroSwitch::ROTAU) == 0 )
+    			{
+    				$additionalInfo = sprintf( "rotau=%s", $temp1 );
+    			}
+
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_LINKS_BACK_TO_AVAILABLE_CODE:
+    			$additionalInfo =$otuAdditionalInfo;
+    			break;
+    			//
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MISSING_REFERENCE_TRACE_CODE:
+    			$parts = explode(',', $otuAdditionalInfo );
+    			if (isset($parts[0]))
+    			{
+    				$temp1 = $parts[0];
+    				if (isset($parts[1]))
+    				{
+    					$temp2 = $parts[1];
+    				}
+    			}
+    			$additionalInfo = sprintf("test=%s", $temp1 );
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SUCCESSFUL_CALLBACK_CODE:
+    			$additionalInfo ="media=".($otuAdditionalInfo);
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_TEST_DRIFT_CODE:
+    			$parts = explode(',', $otuAdditionalInfo );
+    			if (isset($parts[0]))
+    			{
+    				$temp1 = str_replace('"', "", $parts[0] );
+    				if (isset($parts[1]))
+    				{
+    					$temp2 = $parts[1];
+    				}
+    			}
+    			$additionalInfo = sprintf("test=%s", $temp1 );
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_COMMUNICATION_TEST_CODE:
+    			$additionalInfo ="media=".($otuAdditionalInfo);//."/interface=ETH0";
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HEARTBEAT_CODE:
+    			$additionalInfo = $otuAdditionalInfo;//"otu";
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HARDWARE_PROBLEM_CODE:
+    			$additionalInfo =$otuAdditionalInfo;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_SOFTWARE_PROBLEM_CODE:
+    			//$additionalInfo ="component=".($otuAdditionalInfo);
+    			$additionalInfo = $otuAdditionalInfo;//"otu";
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_MEASUREMENT_CYCLE_CODE:
+    			$additionalInfo = $otuAdditionalInfo;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_ALARM_OVERFLOW_CODE:
+    			$additionalInfo = $otuAdditionalInfo;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_GENERIC_ALARM_CODE:
+    			$additionalInfo = $otuAdditionalInfo;//
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_REBUILD_CLEAR_CODE:
+    			$additionalInfo = $otuAdditionalInfo;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HDD_FAILED_CODE:
+    			$additionalInfo = $otuAdditionalInfo;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_HDD_FAILED_USE_BACKUP_CODE:
+    			$additionalInfo = $otuAdditionalInfo;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_ALARM_POWER_FAILURE_CODE:
+    			$additionalInfo = $otuAdditionalInfo;
+    			break;
+    		case SMTAlarmSpecificProblemCode::OTU_SYST_REFERENCE_DRIFT_FAILURE_CODE:
+    			$additionalInfo = $otuAdditionalInfo;
+    			break;
+    		default:
+    			break;
+    	}
+    	
+    	return $additionalInfo;
+    }
 }
 ?>
\ No newline at end of file
