@@ -25,6 +25,7 @@ use app\serviceshelper\SMTServiceHelper;
 use app\util\SMTIOException;
 use app\util\SMTLogger;
 use app\util\SMTUtil;
+use app\settings\SMTSmartOtuSettings;
 
 /**
  *
@@ -131,6 +132,9 @@ class SMTLicence extends SMTServiceHelper
     	unset($_SESSION[SMTLicenseList::OTU_OPTION_TEST_PON_MONITORING]);    	
     	unset($_SESSION[SMTLicenseList::OTU_OPTION_PEAK_MONITORING]);
     	unset($_SESSION[SMTLicenseList::OTU_OPTION_SAA_L2_MONITORING]);
+    	unset($_SESSION[SMTLicenseList::OTU_OPTION_TAPPING_MONITORING]);
+    	unset($_SESSION[SMTLicenseList::OTU_OPTION_LIGHT_SOURCE]);
+    	unset($_SESSION[SMTLicenseList::OTU_OPTION_REST_API]);
     }
     
     /**
@@ -226,6 +230,38 @@ class SMTLicence extends SMTServiceHelper
     	return $peakMonitoring;
     }
     
+    /**
+     * Test whether OTU has Tapping monitoring option.
+     *
+     * @param SMTContext $context
+     *
+     * @return whether the OTU has Tapping monitoring option.
+     */
+    static function isTappingMonitoringOption(SMTContext $context)
+    {
+    	$tappingMonitoring = FALSE;
+    	
+    	if ( isset($_SESSION[SMTLicenseList::OTU_OPTION_TAPPING_MONITORING]) )
+    	{
+    		$tappingMonitoring= $_SESSION[SMTLicenseList::OTU_OPTION_TAPPING_MONITORING];
+    	}
+    	else
+    	{
+    		try
+    		{
+    			$tappingMonitoring = ( strcasecmp( $context->getOtuSocket()->sendReceive( SMTOtuApi::isOtu_Tapping_Monitoring_Option() ), self::OPTION_AVAILABLE) == 0);
+    			
+    			$_SESSION[SMTLicenseList::OTU_OPTION_TAPPING_MONITORING] = $tappingMonitoring;
+    		}
+    		catch ( \Exception $e )
+    		{
+    			SMTLogger::getInstance()->traceException( $e );
+    		}
+    	}
+    	
+    	return $tappingMonitoring;
+    }
+    
     /**
      * Test whether OTU has SAA option.
      *
@@ -257,6 +293,37 @@ class SMTLicence extends SMTServiceHelper
     	return $saa;
     }
     
+    /**
+     * Test whether OTU has REST API option.
+     *
+     * @param SMTContext $context
+     *
+     * @return whether the OTU has REST API option.
+     */
+    static function isRestApiOption(SMTContext $context)
+    {
+    	$RestApi = FALSE;
+    	
+    	if ( SMTSmartOtuSettings::isRestApi() !== NULL )
+    	{
+    		$RestApi= SMTSmartOtuSettings::isRestApi();
+    	}
+    	else
+    	{
+    		try
+    		{
+    			$RestApi = ( $context->getOtuSocket()->sendReceive( SMTOtuApi::isOtu_Rest_Api_Option() ) === self::OPTION_AVAILABLE);
+    			
+    			SMTSmartOtuSettings::setRestApi($RestApi);
+    		}
+    		catch ( \Exception $e )
+    		{
+    			SMTLogger::getInstance()->traceException( $e );
+    		}
+    	}
+    	return $RestApi;
+    }
+    
     /**
      * Returns the software options
      *
