@@ -21,23 +21,29 @@ namespace app\serviceshelper\maintenance;
 final class SMTLicenseList
 {
 	
-	const SSH_KEY_ACCESS= "SSH_KEY_ACCESS";
-	const ENHANCEDSECURITY = "ENHANCEDSECURITY";
-	const PEAK_MON= "PEAK_MON";
-	const DUAL_OS= "DUAL_OS";
-	const EXT_TEMP_RANGE= "EXT_TEMP_RANGE";
-	const PON_TEST= "OTU_PON";
-	const SAA= "SMART_ACCESS_ANYWHERE";
+	const SSH_KEY_ACCESS= 'SSH_KEY_ACCESS';
+	const ENHANCEDSECURITY = 'ENHANCEDSECURITY';
+	const PEAK_MON= 'PEAK_MON';
+	const DUAL_OS= 'DUAL_OS';
+	const EXT_TEMP_RANGE= 'EXT_TEMP_RANGE';
+	const PON_TEST= 'OTU_PON';
+	const SAA= 'SMART_ACCESS_ANYWHERE';
+	const TAPPING_MON= 'OTU_TAPPING';
+	const LIGHT_SOURCE= 'LIGHT_SOURCE';
+	const REST_API= 'REST_API';
 	
-	const OTU_OPTION_HIGH_SEC = "HIGHSEC";
-	const OTU_OPTION_SSH_KEY_ACCESS = "ACCESS";
-	const OTU_OPTION_PEAK_MONITORING = "PEAK";
-	const OTU_OPTION_DUAL_OS_MONITORING = "DUAL_OS";
-	const OTU_OPTION_EXT_TEMP_RANGE_MONITORING = "EXT_TEMP_RANGE";
-	const OTU_OPTION_TEST_PON_MONITORING = "TEST_PON";
-	const OTU_OPTION_SAA_L2_MONITORING = "SAA_L2";	
+	const OTU_OPTION_HIGH_SEC = 'HIGHSEC';
+	const OTU_OPTION_SSH_KEY_ACCESS = 'ACCESS';
+	const OTU_OPTION_PEAK_MONITORING = 'PEAK';
+	const OTU_OPTION_DUAL_OS_MONITORING = 'DUAL_OS';
+	const OTU_OPTION_EXT_TEMP_RANGE_MONITORING = 'EXT_TEMP_RANGE';
+	const OTU_OPTION_TEST_PON_MONITORING = 'TEST_PON';
+	const OTU_OPTION_SAA_L2_MONITORING = 'SAA_L2';
+	const OTU_OPTION_TAPPING_MONITORING = 'TAPPING';
+	const OTU_OPTION_LIGHT_SOURCE= 'LIGHT_SOURCE';
+	const OTU_OPTION_REST_API= 'REST_API';
 
-	const ISU_OPTION_SAA_L2_MONITORING = "SMART_ACCESS_L2";
+	const ISU_OPTION_SAA_L2_MONITORING = 'SMART_ACCESS_L2';
 	
 // NOT VALID IN PHP 5.4 (OTU8Kv2)	
 // 	const OTU_OPTIONS = array(self::OTU_OPTION_HIGH_SEC=>self::SSH_KEY_ACCESS,
@@ -54,7 +60,11 @@ final class SMTLicenseList
 										self::OTU_OPTION_DUAL_OS_MONITORING=>self::DUAL_OS,
 										self::OTU_OPTION_EXT_TEMP_RANGE_MONITORING=>self::EXT_TEMP_RANGE,
 										self::OTU_OPTION_TEST_PON_MONITORING=>self::PON_TEST,
-										self::OTU_OPTION_SAA_L2_MONITORING=>self::SAA);
+										self::OTU_OPTION_SAA_L2_MONITORING=>self::SAA,
+			                            self::OTU_OPTION_TAPPING_MONITORING=>self::TAPPING_MON,
+										self::OTU_OPTION_LIGHT_SOURCE=>self::LIGHT_SOURCE,
+										self::OTU_OPTION_REST_API=>self::REST_API
+	);
 	
 	static function getLicenseName( $scpiKey )
 	{
