@@ -129,7 +129,7 @@ class SMTGpsRoute extends SMTServiceHelper
     {
     	$fileName = null;
     	//retrieve file name
-    	$files = glob( self::GPS_ROUTE_DIR."*".'_'.$linkId.'*.kml');
+    	$files = glob( self::GPS_ROUTE_DIR."*".'_'.$linkId.'??.kml');
     	//search last backup file
     	if ( $files != FALSE && !empty( $files ) )
     	{
@@ -139,9 +139,41 @@ class SMTGpsRoute extends SMTServiceHelper
     			break;
     		}
     	}
+    	//old file format
+    	else
+    	{
+    		$files = glob( self::GPS_ROUTE_DIR."*".'_'.$linkId.'.kml');
+    		//search last backup file
+    		if ( $files != FALSE && !empty( $files ) )
+    		{
+    			foreach ( $files as $file )
+    			{
+    				$fileName = $file;
+    				break;
+    			}
+    		}
+    	}
     	return $fileName;
     }
     
+    /**
+     * Search kml file name from the linkId and remove it
+     * @param integer $linkId
+     */
+    static function removeOldKmlFileName($linkId)
+    {
+    	//retrieve file name
+    	$files = glob( self::GPS_ROUTE_DIR."*".'_'.$linkId.'.kml');
+    	//search old files
+    	if ( $files != FALSE && !empty( $files ) )
+    	{
+    		foreach ( $files as $file )
+    		{
+    			unlink($file);
+    		}
+    	}
+    }
+    
     /**
      * Delete kml file and remove it from link.
      * 
