@@ -151,7 +151,13 @@ abstract class SMTMacroSwitch
     	if ( $decoder != NULL )
     	{
     		$this->globalSwitchEncodedString = $decoder->getSwitchEncodingString();
-    		$osuNumber = $decoder->getOSUCount();		
+    		$osuNumber = $decoder->getOSUCount();
+    		
+    		// distributor OSX musn't be added twice
+    		if ( $osuNumber>= self::OSU_DISTRIBUTOR_INDEX)
+    		{
+    			$osuNumber= self::OSU_DISTRIBUTOR_INDEX -1 ;
+    		}
     	}
     	
     	$decoder = $this->getSwitchDecoder( self::INTERNAL );
