@@ -138,6 +138,27 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     function setOsxAddress($osxAddress)
     {
     	$this->send( sprintf(SMTOtuApi::CMD_set_osx_address, $osxAddress) );
+    	
+    	// force next detection
+    	SMTOtuStatusCacheDto::setSwitchDetectedOnce(FALSE);
+    }
+    
+    
+    /**
+     * Enable/disable sequencer during switch setup
+     *
+     * @param boolean $suspendSequencer TRUE to disable the sequencer
+     */
+    function disableSequencer($suspendSequencer)
+    {
+    	try
+    	{
+    		$this->send( SMTOtuApi::setMonitoringSequensorSuspend($suspendSequencer) );
+    	}
+    	catch( \Exception $e)
+    	{
+    		SMTLogger::getInstance()->traceException($e);
+    	}
     }
     
     /**
@@ -149,8 +170,11 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     {
     	$osxPowerStatus = SMTOtuApi::RES_DISABLED;
     	if ( strcasecmp($osxPower, self::OSX_POWER_ON) == 0 )
-    	{
+    	{	
     		$osxPowerStatus = SMTOtuApi::RES_ENABLED;
+    		
+    		// force next detection
+    		SMTOtuStatusCacheDto::setSwitchDetectedOnce(FALSE);
     	}
     	
      	$this->send( sprintf(SMTOtuApi::CMD_power_on_off_osx, $osxPowerStatus) );
@@ -163,8 +187,14 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
      */
     function getOsxPowerOn()
     {
-     	return strcasecmp( SMTOtuApi::RES_ENABLED, $this->sendReceive( SMTOtuApi::CMD_get_power_on_off_osx ) ) == 0;
-//     	return TRUE;
+    	if ( SMTOtuType::isCOtu())
+    	{
+    		return strcasecmp( SMTOtuApi::RES_ENABLED, $this->sendReceive( SMTOtuApi::CMD_get_power_on_off_osx ) ) == 0;    		
+    	}
+    	else
+    	{
+    		return TRUE;
+    	}
     }
     
     /**
@@ -176,6 +206,9 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     static function setBigTopology($bigTopology, SMTOtuSocket $socket)
     {
     	$socket->send( sprintf(SMTOtuApi::CMD_set_bigtopo, 0, $bigTopology) );
+    	
+    	// force next detection
+    	SMTOtuStatusCacheDto::setSwitchDetectedOnce(FALSE);
     }
     
     /**
@@ -232,6 +265,9 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     	// save scan in memory
     	$osxList->save();
     	
+    	// force next detection
+    	SMTOtuStatusCacheDto::setSwitchDetectedOnce(FALSE);
+    	
     	return $osxList;
     }
     
@@ -308,7 +344,8 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
      */
     static function applySwitchDetected(SMTOtuSocket $socket)
     {
-        $detectedSwitch = self::retrieveDetectedSwitch($socket);
+    	// on ne detecte les OSXs que s'ils n'ont pas ete deja detectes
+    	$detectedSwitch = self::retrieveDetectedSwitch($socket, SMTOtuStatusCacheDto::getSwitchDetectedOnce());
                 
         if ( $detectedSwitch != NULL )
         {
@@ -319,6 +356,9 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
         		{
         			SMTLogger::getInstance()->trace("applySwitchDetected >> setBigTopology incomplete FALSE", SMTLogger::PINFO );
         			SMTSwitchManager::setBigTopology('FALSE', $socket);
+        			
+        			// on force la detection avec la topologie etendue
+        			$detectedSwitch = self::retrieveDetectedSwitch($socket, TRUE);
         		}
         		catch ( \Exception $e )
         		{
@@ -434,11 +474,11 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
         //search if macro switch exists
         if ($forceDetection)
             {
-            $switchDetectMacroResult = $socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_macro, self::MACRO_SWITCH_ID ) );
+            	$switchDetectMacroResult = $socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_macro, self::MACRO_SWITCH_ID ), SMTOtuSocket::DEFAULT_SLEEP, 90);
             }
         else
             {
-            $switchDetectMacroResult = $socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_result, self::MACRO_SWITCH_ID ) );
+            	$switchDetectMacroResult = $socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_result, self::MACRO_SWITCH_ID ), SMTOtuSocket::DEFAULT_SLEEP, 90);
             }        
         $macroSwitchExist = strcasecmp( $switchDetectMacroResult, SMTOtuApi::RES_ON) == 0;
         
@@ -458,7 +498,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
      */
     static function retrieveDetectedSwitchHomogeneous(SMTOtuSocket $socket)
     {
-    	$result = $socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_osu_homogeneous, self::MACRO_SWITCH_ID ) );
+    	$result = $socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_osu_homogeneous, self::MACRO_SWITCH_ID ), SMTOtuSocket::DEFAULT_SLEEP, 90 );
     	return strcasecmp( $result, SMTOtuApi::RES_SAME) == 0;
     }
     
