@@ -186,7 +186,7 @@ function checkPatch($filename, SMTContext $context)
 //
 //
 /////////////////////////////////////////////////////////////////////////////////////////
-function checkReleaseExtension($filename)
+function check8kReleaseExtension($filename)
 {
 	return ( (strpos($filename, '8kv2') !== FALSE) && SMTUtil::endsWith( $filename, '.tar.gz') );
 }
