@@ -13,8 +13,6 @@
 // *********************************************************
 namespace app\view;
 
-use app\http\SMTSessionDirectoryUtil;
-use app\serviceshelper\otdr\SMTOtdrTraceFileUtil;
 use app\util\SMTIOException;
 
 /**
@@ -22,14 +20,8 @@ use app\util\SMTIOException;
  *
  * @author Sylvain Desplat
  */
-class SMTOtdrTraceFileDownloadPage implements SMTIPage
+class SMTOtdrTraceFileDownloadPage extends SMTOtdrTraceBaseDownloadPage
 {
-	private $FILES_ALLOWED_FOR_DOWNLOAD = array('sor','csor','msor');
-	private $DIRECTORIES_ALLOWED_FOR_DOWNLOAD = array(SMTSessionDirectoryUtil::CUSTOM_SMARTOTU_SESSION_DIR, SMTOtdrTraceFileUtil::OTU_TEST_RESULT_DET_DIR, SMTOtdrTraceFileUtil::OTU_TEST_RESULT_LOC_DIR, SMTOtdrTraceFileUtil::OTU_MEASURE_ON_DEMAND_DIR,SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR, SMTOtdrTraceFileUtil::OTU_MEASURE_REF_LOC_DIR, SMTOtdrTraceFileUtil::CUSTOM_SMARTOTU_ALARM_DIR,SMTOtdrTraceFileUtil::OTU_RESULT_DET_DIR, SMTOtdrTraceFileUtil::OTU_RESULT_LOC_DIR);
-	
-	private $otdrTracefileName;
-	private $otdrTraceType;
-	
 	/**
 	 * Construct the builder of otdr trace file.
 	 * 
@@ -42,31 +34,6 @@ class SMTOtdrTraceFileDownloadPage implements SMTIPage
 		$this->otdrTracefileName = $otdrTracefileName;
 		$this->otdrTraceType = $otdrTraceType;
 	}
-	
-	/**
-	 * Only a few type of files are allowed to be downloaded
-	 *
-	 * @param string $fileName
-	 * @return boolean
-	 */
-	function checkFileExtension($fileName)
-	{
-		$ext = pathinfo($fileName, PATHINFO_EXTENSION);
-		return in_array($ext, $this->FILES_ALLOWED_FOR_DOWNLOAD);
-	}
-	
-	/**
-	 * Only a few directories are allowed for download
-	 *
-	 * @param string $fileName
-	 * @return boolean
-	 */
-	function checkDirectory($fileName)
-	{
-		$dir = pathinfo($fileName, PATHINFO_DIRNAME).'/';
-// 		SMTLogger::getInstance()->trace($dir);
-		return in_array($dir, $this->DIRECTORIES_ALLOWED_FOR_DOWNLOAD) || (strpos($dir, SMTSessionDirectoryUtil::CUSTOM_SMARTOTU_SESSION_DIR) !== false);
-	}
 
 	/**
 	 * Flush the otdr trace buffer for the given otdr trace file name
