@@ -71,6 +71,9 @@ class Restler extends EventEmitter
      */
     public $requestData = array();
 
+    
+    public $textRequestData;
+    
     /**
      * Used in production mode to store the routes and more
      *
@@ -984,6 +987,15 @@ class Restler extends EventEmitter
         }
     }
 
+    /**
+     * Returns the text request data after it has been parsed by getRequestData()
+     *
+     * @return array php data
+     */
+    public function getTestRequestData()
+    {
+    	return $this->textRequestData;
+    }
     /**
      * Parses the request data and returns it
      *
@@ -999,11 +1011,12 @@ class Restler extends EventEmitter
                 return $this->requestData;
             }
             try {
-                $r = file_get_contents('php://input');
-                if (is_null($r)) {
+            	$this->textRequestData = file_get_contents('php://input');
+            	if (is_null($this->textRequestData)) 
+            	{
                     return array();
                 }
-                $r = $this->requestFormat->decode($r);
+                $r = $this->requestFormat->decode($this->textRequestData);
                 return is_null($r) ? array() : $r;
             } catch (RestException $e) {
                 $this->handleError($e->getCode(), $e->getMessage());
