@@ -34,7 +34,7 @@ rm -f $TMP_SSH_RESULT
 rm -f $TMP_SSH_PID
 
 # lancement et detachement de ssh en mode tunnel, timeout a 15 secondes
-ssh -o ConnectTimeout=$TESTTIMEOUT -i /root/.ssh/otu_id_rsa -L $LPORT:localhost:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
+ssh -o ConnectTimeout=$TESTTIMEOUT -L $LPORT:localhost:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
 
 # get PID as command returned value, and save to file
 PID=$!
