@@ -13,7 +13,7 @@ STATUS=`echo $?`
 
 if [[ $STATUS -eq 0 ]]; then
     cd "$Temp_Dir"
-    /usr/bin/gpg --import "/root/.gnupg/pubring.gpg"
+    /usr/bin/gpg --import "/usr/share/secrelease/viavi.gpg"
     /usr/bin/gpg --verify "$File_To_Check.sig" "$File_To_Check"
     STATUS=`echo $?`
 fi
@@ -34,7 +34,7 @@ fi
 [[ $File_Count -gt 5 ]] && { STATUS=1; }
 
 if [[ $STATUS -eq 0 ]]; then
-    /usr/bin/gpg --import "/root/.gnupg/pubring.gpg"
+    /usr/bin/gpg --import "/usr/share/secrelease/viavi.gpg"
     /usr/bin/gpg --verify "$File_To_Check.sig" "$File_To_Check"
     STATUS=`echo $?`
 fi
