@@ -4,16 +4,16 @@ from __future__ import print_function
 import parted, os, sys, time
 import tarfile
 import subprocess
-from shutil import copyfile
+from shutil import copyfile, SameFileError
 import xml.etree.ElementTree as etree
 try:
     from urllib.request import urlopen
 except ImportError:
     from urllib2 import urlopen
 try:
-    from .blockutils import get_block_devices, PARTITION_8GB, mount, umount, mount_bind, get_partition_plan
+    from .blockutils import get_block_devices, get_partition_plan, mount, umount, mount_bind, get_partition_plan
 except:
-    from blockutils import get_block_devices, PARTITION_8GB, mount, umount, mount_bind, get_partition_plan
+    from blockutils import get_block_devices, get_partition_plan, mount, umount, mount_bind, get_partition_plan
 
 GRAY =   (0xBB, 0xBB, 0xBB)
 BLACK =   (0x0, 0x0, 0x0)
@@ -29,8 +29,8 @@ def progress_bar(gui, value):
         if value != last_pbar:
             last_pbar = value
             gui.rectangle(50,250, int((value * 700) / 100),50,BLUE)
-            print("\rInstall %i%%"%value, end='')
-
+            print("Install %i%%"%value)
+            sys.stdout.flush()
 
 def sync():
     try:
@@ -115,13 +115,19 @@ def StreamDecorator(original, tarsize, notify):
     return original
 
 def printme(self, percent):
-    print("\rInstall %i%%"%percent, end='')
+    if(percent % 5 != 0):
+        return
+
+    if percent != printme.last:
+        printme.last = percent
+        print("# Install %i%%"%percent)
+printme.last = 120
+
 
 def install_image(uri, notifier=printme, gui=None):
     sync()
     if gui:
         def print_gui(self,percent):
-            print("\rInstall %i%%"%percent, end='')
             progress_bar(gui, percent)
         notifier = print_gui
     f = urlopen(uri)
@@ -143,7 +149,12 @@ def mount_chroot(path="/mnt/fs"):
     mount_bind("/dev/", "%s/dev/"%path)
     mount("none", "%s/sys"%path, "sysfs")
     mount("none", "%s/proc"%path, "proc")
-    copyfile("/etc/resolv.conf", "%s/etc/resolv.conf"%path)
+    try:
+        copyfile("/etc/resolv.conf", "%s/etc/resolv.conf"%path)
+    except SameFileError:
+        pass
+    except FileNotFoundError:
+        open("%s/etc/resolv.conf"%path, 'a').close()
 
 def umount_chroot(path="/mnt/fs"):
     umount("%s/dev"%path)
@@ -160,11 +171,13 @@ def chroot_exec(path, command):
     os.close(real_root)
 
 def install_release(releasexml, firstinstall=True, part=5, gui=None):
+    result = False
     mmc = list(get_block_devices("MMC").keys())[0]
+    partitiontable = get_partition_plan()
     if firstinstall:
-        create_partitions_table(mmc, PARTITION_8GB)
+        create_partitions_table(mmc, partitiontable)
     else:
-        re_format_device(mmc, PARTITION_8GB, part)
+        re_format_device(mmc, partitiontable, part)
     try:
         mount_target(mmc, part)
         if gui:
@@ -178,17 +191,19 @@ def install_release(releasexml, firstinstall=True, part=5, gui=None):
                 os.makedirs("/mnt/fs/boot/env.d")
             chroot_exec("/mnt/fs", ["/usr/sbin/run-postinsts"])
             chroot_exec("/mnt/fs", ["/sbin/fw_setenv", "mmc_part", "%i"%part])
+            result = True
         finally:
             umount_chroot()
     finally:
         umount_target()
+    return result
 
 def install_pmulti(uri, firstinstall=True, part=7):
     mmc = list(get_block_devices("MMC").keys())[0]
     if firstinstall:
-        create_partitions_table(mmc, PARTITION_8GB)
+        create_partitions_table(mmc, get_partition_plan())
     else:
-        re_format_device(mmc, PARTITION_8GB, part)
+        re_format_device(mmc, get_partition_plan(), part)
     try:
         mount("/dev/%sp%i"%(mmc, part), "/mnt/fs/", "ext4")
         sync()
@@ -200,11 +215,16 @@ def install_pmulti(uri, firstinstall=True, part=7):
         pmultiuri = uri.replace('release.xml', pmultiname)
         r = urlopen(pmultiuri)
         with open("/mnt/fs/pmulti.itb", "wb") as pm:
-            pm.write(r.read())
+            while(True):
+                stream = r.read(1*1024*1024) # Read 1MB
+                if(len(stream) == 0):
+                    break
+                pm.write(stream)
         sync()
     finally:
         umount("/mnt/fs")
 
+
 if __name__ == "__main__":
     if len(sys.argv) < 2:
         print("%s [-f] http://server/release.xml\n\t-f: Force full format device (!!! Will loose Calibration !!!)"%sys.argv[0])
@@ -217,6 +237,9 @@ if __name__ == "__main__":
         gui = FrameBuffer("/dev/fb0")
         gui.rectangle(0,300,800,180,BLACK)
         gui.rectangle(50,250,700,50,GRAY)
-        install_release(sys.argv[2], False, gui=gui)
+        if install_release(sys.argv[2], False, gui=gui):
+            print("Filesystem successfully installed")
+            exit(0)
+        exit(-1)
     else:
         install_release(sys.argv[1], False)
