@@ -2,7 +2,7 @@
 # coding: utf-8 
 # machine: eotdrv2
 
-ver='28-09-2018'
+ver='05-12-2018'
 
 from importlib import reload
 from jdsu.evm import *          # dans /usr/lib/python3.5/jdsu/evm contient O()... , print_info....
@@ -1104,25 +1104,22 @@ def PID_set(Kp=None,KpDecal=None,Ki=None,KiDecal=None,Kd=None,KdDecal=None):
     if KdDecal!=None:
         otdr.utsbdt.rw_register(UtsBdt.WRITE, REG_PID_Kd, 0x00FF0000, KdDecal<<16 )#sans toucher au bit de poids fort (enable PID num)
     PID_enable(1)
-    setTempTEC(25,wait=False)
+    #~ setTempTEC(25,wait=False)
 
 def PID_status():
     otdr=Otdr_Acq()
     Status_reg=otdr.utsbdt.rw_register(UtsBdt.READ, REG_PID_STATUS,  0, 0)    
-    fifo_empty=(Status_reg&0x10000000)>>28
-    fifo_full=(Status_reg&0x20000000)>>29
-    while not fifo_empty:
+    tec_auto = 0
+    while 1:
         Log_reg=otdr.utsbdt.rw_register(UtsBdt.READ, REG_PID_LOG,  0, 0)
+        val=otdr.utsbdt.rw_register(UtsBdt.READ, REG_DAC_CONSIGNE_TEC,  0, 0)
+        tec_auto = (val&0x10000)>>16
         DAC=(Log_reg&0xffff0000)>>16
         ADC=(Log_reg&0xffff)
         Status_reg=otdr.utsbdt.rw_register(UtsBdt.READ, REG_PID_STATUS,  0, 0)    
-        fifo_empty=(Status_reg&0x10000000)>>28
-        fifo_full=(Status_reg&0x20000000)>>29
         overf=(Status_reg&0x80000000)>>31 
         underf=(Status_reg&0x40000000)>>30 
-        print('DAC=0x%04X ADC=0x%04X F=%d O=%d U=%d'%(DAC,ADC,fifo_full,overf,underf))
-        if(fifo_full):
-            print('***************************')
+        print('DAC=0x%04X ADC=0x%04X AUTO=%d O=%d U=%d'%(DAC,ADC,tec_auto,overf,underf))
 
 def PID_readRegs(repeat=False):
     otdr=Otdr_Acq()
